/*
 * hi6403_regs.h -- HI6403 ALSA SoC HI6403 codec driver
 *
 * Copyright (c) 2015 Hisilicon Technologies CO., Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 */
/*
 * hi6403_regs.h
 *
 * hi6403 regs define
 *
 * Copyright (c) 2015-2019 Huawei Technologies Co., Ltd.
 *
 * This software is licensed under the terms of the GNU General Public
 * License version 2, as published by the Free Software Foundation, and
 * may be copied, distributed, and modified under those terms.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 */

#ifndef __DA_COMBINE_V3_REGS_H__
#define __DA_COMBINE_V3_REGS_H__
#include "hi64xx_regs.h"

/* offset of reg */
#define BASE_OFFSET 0x20000000

#define BASE_ADDR_PAGE_EDMA     0x0000
#define BASE_ADDR_PAGE_WDOG     0x2000
#define BASE_ADDR_PAGE_SCTRL    0x3000
#define BASE_ADDR_PAGE_UART     0x4000
#define BASE_ADDR_PAGE_TIMER0   0x5000
#define BASE_ADDR_PAGE_TIMER1   0x6000
#define BASE_ADDR_PAGE_ANA      0x7100
#define BASE_ADDR_PAGE_GPIO0    0x8000
#define BASE_ADDR_PAGE_GPIO1    0x9000
#define BASE_ADDR_PAGE_GPIO2    0xA000
#define BASE_ADDR_PAGE_GPIO3    0xB000
#define BASE_ADDR_PAGE_I2C_MST  0xC000
#define BASE_ADDR_PAGE_DSPIF    0x10000

#define BASE_ADDR_PAGE_OCRAM    0x10000000
#define BASE_ADDR_PAGE_TCM      0x08000000

#define HI6403_PAGE_IO_START 0x0
#define HI6403_PAGE_IO_END 0x290
#define HI6403_PAGE_CFG_START 0x0
#define HI6403_PAGE_CFG_END 0xA5

#define HI6403_PAGE_DIG_OFFSET_START    0x0
#define HI6403_PAGE_DIG_OFFSET_END      0x3AA

#define HI6403_PAGE_ANA_OFFSET_START    0x0
#define HI6403_PAGE_ANA_OFFSET_END      0xFF

#define HI6403_PAGE_EDMA_OFFSET_START 0x0
#define HI6403_PAGE_EDMA_OFFSET_END 0xC1C
#define HI6403_PAGE_WDOG_OFFSET_START 0x0
#define HI6403_PAGE_WDOG_OFFSET_END 0xC00

#define HI6403_PAGE_SCTRL_OFFSET_START 0x0
#define HI6403_PAGE_SCTRL_OFFSET_END 0x128
#define HI6403_PAGE_UART_OFFSET_START 0x0
#define HI6403_PAGE_UART_OFFSET_END 0xFC

#define HI6403_PAGE_TIMER0_OFFSET_START 0x0
#define HI6403_PAGE_TIMER0_OFFSET_END 0x38
#define HI6403_PAGE_TIMER1_OFFSET_START 0x0
#define HI6403_PAGE_TIMER1_OFFSET_END 0x38

#define HI6403_PAGE_GPIO0_OFFSET_START  0x0
#define HI6403_PAGE_GPIO0_OFFSET_END    0x534
#define HI6403_PAGE_GPIO1_OFFSET_START  0x0
#define HI6403_PAGE_GPIO1_OFFSET_END    0x534
#define HI6403_PAGE_GPIO2_OFFSET_START  0x0
#define HI6403_PAGE_GPIO2_OFFSET_END    0x534
#define HI6403_PAGE_GPIO3_OFFSET_START  0x0
#define HI6403_PAGE_GPIO3_OFFSET_END    0x534

#define HI6403_PAGE_I2C_MST_OFFSET_START  0x0
#define HI6403_PAGE_I2C_MST_OFFSET_END    0xFC

#define HI6403_PAGE_DSPIF_OFFSET_START 0x0
#define HI6403_PAGE_DSPIF_OFFSET_END 0x8FFF

#define HI6403_PAGE_OCRAM_START 0x0
#define HI6403_PAGE_OCRAM_END 0x57fff

#define HI6403_PAGE_TCM_START 0x0
#define HI6403_PAGE_TCM_END 0x0002FFFF

#define HI6403_PAGE_VIRTUAL_START 0x0
#define HI6403_PAGE_VIRTUAL_END 0x6

/* page base addr def end */
#define HI6403_VERSION_REG   (CODEC_BASE_ADDR + BASE_ADDR_PAGE_CFG + 0x0)

/* vir mm reg begin */
#define HI6403_VIRTUAL_REG (BASE_ADDR_PAGE_MM + 0x0)
#define HI6403_S4_OL_SRC_EN_MM_BIT      0
#define HI6403_S4_OR_SRC_EN_MM_BIT      1
#define HI6403_AUDIOUP_BIT              2
#define HI6403_VOICEUP_BIT              3
#define HI6403_PLL48K_BIT               4
#define HI6403_PLL44K1_BIT              5
#define HI6403_PLLMAD_BIT               6
#define HI6403_VOICE8K_BIT              7
#define HI6403_VOICE16K_BIT             8
#define HI6403_S3_OL_SRC_EN_MM_BIT      9
#define HI6403_S3_OR_SRC_EN_MM_BIT      10
#define HI6403_U3_OL_SRC_EN_MM_BIT      11
#define HI6403_U4_OR_SRC_EN_MM_BIT      12
#define HI6403_AUDIOUP_4MIC_BIT         13
#define HI6403_S1_OL_SRC_EN_MM_BIT      14
#define HI6403_S1_OR_SRC_EN_MM_BIT      15
#define HI6403_HPCLASSH_BIT             16
#define HI6403_VOICE32K_BIT             17
#define HI6403_PLAY48K_BIT              18
#define HI6403_PLAY96K_BIT              19
#define HI6403_PLAY192K_BIT             20
#define HI6403_LOWLANTENCY_BIT          21

#ifdef CONFIG_BUCKBOOST
#define HI6403_AUXMICPWMPOWER_BIT       22
#endif

#define HI6403_IR_ENV_STUDY_BIT         23
#define HI6403_I2S2_BLUETOOTH_LOOP_BIT  24

#define HI6403_SOUNDTRIGGER_ONE_MIC_EN_BIT    25
#define HI6403_SOUNDTRIGGER_DUAL_MIC_EN_BIT   26
#define HI6403_SOUNDTRIGGER_MULTI_MIC_EN_BIT  27

/* vir mm reg end */

/* cfg reg begin */
#define HI6403_PLL44K1_PLLMAD_STATE_REG (BASE_ADDR_PAGE_CFG + 0x01C)
#define HI6403_PLL48K_STATE_REG         (BASE_ADDR_PAGE_CFG + 0x01D)
#define HI6403_12M288_CLK_SEL_REG       (BASE_ADDR_PAGE_CFG + 0x04D)
#define HI6403_DSP_CLK_SW_BIT           0
#define HI6403_PLL_LOCK_CFG_REG         (BASE_ADDR_PAGE_CFG + 0x0A0)
#define HI6403_PLL_LOCK_CLR_BIT         3
#define HI6403_PLL_LOCK_CHECK_BIT       2
#define HI6403_AUDIO_CLK_CFG_REG (BASE_ADDR_PAGE_CFG + 0x040)
#define HI6403_HPDN_44K1CLK_SEL_BIT     6
#define HI6403_S4_44K1CLK_SEL_BIT       5
#define HI6403_S1_44K1CLK_SEL_BIT       4
#define HI6403_ADUIO_5M6448CLK_EN_BIT   3
#define HI6403_ADUIO_6M144CLK_EN_BIT    2
#define HI6403_ADUIO_11M2896CLK_EN_BIT  1
#define HI6403_ADUIO_12M288CLK_EN_BIT   0
#define HI6403_DIG_CLK_CFG_REG05    (BASE_ADDR_PAGE_CFG + 0x045)
#define HI6403_HP_DET_CLKEN_BIT     5
#define HI6403_CLASSH_CLKEN_BIT     4
#define	HI6403_ANC_CLKEN_BIT        3
#define HI6403_MAD_CLK_CFG_BIT      0

#define HI6403_DIG_CLK_CFG_REG06    (BASE_ADDR_PAGE_CFG + 0x046)
#define HI6403_ADC0R_PGA_CLKEN_BIT  7
#define HI6403_ADC0L_PGA_CLKEN_BIT  6
#define HI6403_DACRS_UP16_CLKEN_BIT 5
#define HI6403_DACLS_UP16_CLKEN_BIT 4
#define HI6403_VOICE_UP_RST_BIT     3
#define HI6403_AUDIO_UP_RST_BIT     2
#define HI6403_DACR_UP16_CLKEN_BIT  1
#define HI6403_DACL_UP16_CLKEN_BIT  0

#define HI6403_DIG_CLK_CFG_REG07     (BASE_ADDR_PAGE_CFG + 0x047)
#define HI6403_ADC1R_PGA_CLKEN_BIT   7
#define HI6403_ADC1L_PGA_CLKEN_BIT   6
#define HI6403_DACR_SRC_CLKEN_BIT    5
#define HI6403_DACL_SRC_CLKEN_BIT    4
#define HI6403_DACRS_MIXER_CLKEN_BIT 3
#define HI6403_DACLS_MIXER_CLKEN_BIT 2
#define HI6403_DACR_MIXER_CLKEN_BIT  1
#define HI6403_DARL_MIXER_CLKEN_BIT  0

#define HI6403_DIG_CLK_CFG_REG08     (BASE_ADDR_PAGE_CFG + 0x048)
#define HI6403_DSDR_SDM_CLKEN_BIT    5
#define HI6403_DSDL_SDM_CLKEN_BIT    4
#define HI6403_DACRS_SDM_CLKEN_BIT   3
#define HI6403_DACLS_SDM_CLKEN_BIT   2
#define HI6403_DACR_SDM_CLKEN_BIT    1
#define HI6403_DACL_SDM_CLKEN_BIT    0

#define HI6403_DIG_CLK_CFG_REG09     (BASE_ADDR_PAGE_CFG + 0x049)
#define HI6403_DACRS_CLKEN_BIT       7
#define HI6403_DACLS_CLKEN_BIT       6
#define HI6403_DACR_CLKEN_BIT        5
#define HI6403_DACL_CLKEN_BIT        4
#define HI6403_ADC1R_CLKEN_BIT       3
#define HI6403_ADC1L_CLKEN_BIT       2
#define HI6403_ADC0R_CLKEN_BIT       1
#define HI6403_ADC0L_CLKEN_BIT       0

#define HI6403_DIG_CLK_CFG_REG10     (BASE_ADDR_PAGE_CFG + 0x04A)
#define HI6403_DACR_PGA_CLKEN_BIT    7
#define HI6403_DACL_PGA_CLKEN_BIT    6
#define HI6403_PDM_CLKEN_BIT         3
#define HI6403_MDM_SRC_CLKEN_BIT     2
#define HI6403_SIDE_PGA_CLKEN_BIT    1
#define HI6403_SIDE_SRC_CLKEN_BIT    0

#define HI6403_DIG_CLK_CFG_REG11     (BASE_ADDR_PAGE_CFG + 0x04B)
#define HI6403_DACLS_PGA_CLKEN_BIT   7
#define HI6403_DMIC0_CLK_CFG_BIT     4
#define HI6403_DMIC1_IF_CLKEN_BIT    3
#define HI6403_DMIC1_CLKEN_BIT       2
#define HI6403_DMIC0_IF_CLKEN_BIT    1
#define HI6403_DMIC0_CLKEN_BIT       0

#define HI6403_DIG_CLK_CFG_REG12        (BASE_ADDR_PAGE_CFG + 0x04C)
#define HI6403_DMIC01_CLK_CFG_BIT       4
#define HI6403_DACR_FLT_MIXER_CLKEN_BIT 3
#define HI6403_DACL_FLT_MIXER_CLKEN_BIT 2
#define HI6403_DACR_SRC_MIXER_CLKEN_BIT 1
#define HI6403_DACL_SRC_MIXER_CLKEN_BIT 0

#define HI6403_CFG_CLK_CTRL         (BASE_ADDR_PAGE_CFG + 0x02F)
#define HI6403_SLIM_CLK_DIV_REG     (BASE_ADDR_PAGE_CFG + 0x030)
#define HI6403_SLIM_CTRL3            (BASE_ADDR_PAGE_CFG + 0x033)
#define HI6403_S1_PORT_CLKEN_REG    (BASE_ADDR_PAGE_CFG + 0x041)
#define HI6403_S1_OR_SRC_CLKEN_BIT  7
#define HI6403_S1_OL_SRC_CLKEN_BIT  6
#define HI6403_S1_OR_PGA_CLKEN_BIT  5
#define HI6403_S1_OL_PGA_CLKEN_BIT  4
#define HI6403_S1_IR_SRC_CLKEN_BIT  3
#define HI6403_S1_IL_SRC_CLKEN_BIT  2
#define HI6403_S1_IR_PGA_CLKEN_BIT  1
#define HI6403_S1_IL_PGA_CLKEN_BIT  0

#define HI6403_S2_PORT_CLKEN_REG    (BASE_ADDR_PAGE_CFG + 0x042)
#define HI6403_S2_OR_SRC_CLKEN_BIT  7
#define HI6403_S2_OL_SRC_CLKEN_BIT  6
#define HI6403_S2_OR_PGA_CLKEN_BIT  5
#define HI6403_S2_OL_PGA_CLKEN_BIT  4
#define HI6403_S2_IR_SRC_CLKEN_BIT  3
#define HI6403_S2_IL_SRC_CLKEN_BIT  2
#define HI6403_S2_IR_PGA_CLKEN_BIT  1
#define HI6403_S2_IL_PGA_CLKEN_BIT  0

#define HI6403_S3_PORT_CLKEN_REG    (BASE_ADDR_PAGE_CFG + 0x043)
#define HI6403_S3_OR_SRC_CLKEN_BIT  7
#define HI6403_S3_OL_SRC_CLKEN_BIT  6
#define HI6403_S3_OR_PGA_CLKEN_BIT  5
#define HI6403_S3_OL_PGA_CLKEN_BIT  4
#define HI6403_S3_IR_SRC_CLKEN_BIT  3
#define HI6403_S3_IL_SRC_CLKEN_BIT  2
#define HI6403_S3_IR_PGA_CLKEN_BIT  1
#define HI6403_S3_IL_PGA_CLKEN_BIT  0

#define HI6403_S4_PORT_CLKEN_REG    (BASE_ADDR_PAGE_CFG + 0x044)
#define HI6403_S4_OR_SRC_CLKEN_BIT  7
#define HI6403_S4_OL_SRC_CLKEN_BIT  6
#define HI6403_S4_SMARTR_CLKEN_BIT  5
#define HI6403_S4_SMARTL_CLKEN_BIT  4
#define HI6403_DMIC_RST_BIT         3
#define HI6403_S1_MAD_SRC_CLKEN_BIT 2
#define HI6403_S1_SMARTR_CLKEN_BIT  1
#define HI6403_S1_SMARTL_CLKEN_BIT  0

/* MIXER CLK ENABLE */
#define HI6403_DAC_MIXER_CLK_REG           (BASE_ADDR_PAGE_CFG + 0x047)
#define HI6403_DACSR_MIXER_EN_BIT          3
#define HI6403_DACSL_MIXER_EN_BIT          2
#define HI6403_DACR_MIXER_EN_BIT           1
#define HI6403_DACL_MIXER_EN_BIT           0

#define HI6403_DAC_SRC_MIXER_CLK_REG       (BASE_ADDR_PAGE_CFG + 0x04C)
#define HI6403_DACR_FLT_MIXER_EN_BIT       3
#define HI6403_DACL_FLT_MIXER_EN_BIT       2
#define HI6403_DACR_SRC_MIXER_EN_BIT       1
#define HI6403_DACL_SRC_MIXER_EN_BIT       0

#define HI6403_DSD_CLK_CFG_REG0            (BASE_ADDR_PAGE_CFG + 0x096)
#define HI6403_DSD_CLK_CFG_REG1            (BASE_ADDR_PAGE_CFG + 0x097)

#define HI6403_MAD_AUTO_SWITCH_REG         (BASE_ADDR_PAGE_CFG + 0x0A1)
#define HI6403_MAD_AUTO_SWITCH_BIT         0

#define HI6403_PLL_STATUS_REG              (BASE_ADDR_PAGE_CFG + 0x0A4)
#define HI6403_PLLMAD_LOCK_BIT             4
#define HI6403_PLL44K1_LOCK_BIT            2
#define HI6403_PLL48K_LOCK_BIT             0

/* hi_cdcctrl will use this addr,so it should be full addr */
#define HI6403_IRQ_REG0_REG             (CODEC_BASE_ADDR + BASE_ADDR_PAGE_CFG + 0x014)
#define HI6403_IRQ_REG1_REG             (CODEC_BASE_ADDR + BASE_ADDR_PAGE_CFG + 0x015)
#define HI6403_IRQ_REG2_REG             (CODEC_BASE_ADDR + BASE_ADDR_PAGE_CFG + 0x016)
#define PLL48K_ULOCK_IRQ_BIT            4
#define HI6403_IRQ_REG3_REG             (CODEC_BASE_ADDR + BASE_ADDR_PAGE_CFG + 0x02D)
#define HI6403_IRQ_REG4_REG             (CODEC_BASE_ADDR + BASE_ADDR_PAGE_CFG + 0x071)
#define PLLMAD_ULOCK_IRQ_BIT            4
#define PLL44K1_ULOCK_IRQ_BIT           2
#define HI6403_IRQ_REG5_REG             (CODEC_BASE_ADDR + BASE_ADDR_PAGE_CFG + 0x085)
#define CP2_SHORT_IRQ_BIT               5
#define CP1_SHORT_IRQ_BIT               4
#define BUNK2_SCP_IRQ_BIT               3
#define BUNK2_OCP_IRQ_BIT               2
#define BUNK1_SCP_IRQ_BIT               1
#define BUNK1_OCP_IRQ_BIT               0
#define HI6403_IRQM_REG0_REG            (CODEC_BASE_ADDR + BASE_ADDR_PAGE_CFG + 0x017)
#define HI6403_IRQM_REG1_REG            (CODEC_BASE_ADDR + BASE_ADDR_PAGE_CFG + 0x018)
#define HI6403_IRQM_REG2_REG            (CODEC_BASE_ADDR + BASE_ADDR_PAGE_CFG + 0x019)
#define HI6403_IRQM_REG3_REG            (CODEC_BASE_ADDR + BASE_ADDR_PAGE_CFG + 0x02C)
#define HI6403_IRQM_REG4_REG            (CODEC_BASE_ADDR + BASE_ADDR_PAGE_CFG + 0x070)
#define HI6403_IRQM_REG5_REG            (CODEC_BASE_ADDR + BASE_ADDR_PAGE_CFG + 0x084)

/* cfg reg end */

/* io reg begin */
#define HI6403_IOSHARE_PIN_IE           8
#define HI6403_IOSHARE_PIN_OE           7
#define HI6403_IOSHARE_PIN_PD           6
#define HI6403_IOSHARE_PIN_PU           5
#define HI6403_IOSHARE_PIN_DS           2
#define HI6403_IOSHARE_PIN_SL           1
#define HI6403_IOSHARE_PIN_ST           0

#define HI6403_GPIO0_IOSHARE_REG        (BASE_ADDR_PAGE_IO + 0x000)
#define HI6403_IOTEST0_EN_BIT           4
#define HI6403_GPIO0_EN_BIT             3
#define HI6403_I2C_SLV_CLK_EN_BIT       1
#define HI6403_SSI_DATA_IOSHARE_REG     (BASE_ADDR_PAGE_IO + 0x004)
#define HI6403_GPIO5_EN_BIT             3
#define HI6403_I2C_SLV_DATA_BIT         1
#define HI6403_SSI_DATA_EN_BIT          0
#define HI6403_IRQ_IOSHARE_REG          (BASE_ADDR_PAGE_IO + 0x008)
#define HI6403_IOTEST1_EN_BIT           4
#define HI6403_GPIO6_EN_BIT             3
#define HI6403_IRQ_EN_BIT               0
#define HI6403_I2S1_SYNC_IOSHARE_REG    (BASE_ADDR_PAGE_IO + 0x00C)
#define HI6403_GPIO7_EN_BIT             3
#define HI6403_SLIM_DATA_EN_BIT         1
#define HI6403_I2S1_SYNC_EN_BIT         0
#define HI6403_I2S1_CLK_IOSHARE_REG     (BASE_ADDR_PAGE_IO + 0x010)
#define HI6403_GPIO8_EN_BIT             3
#define HI6403_SLIM_CLK_EN_BIT          1
#define HI6403_I2S1_CLK_EN_BIT          0
#define HI6403_I2S1_SDI_IOSHARE_REG     (BASE_ADDR_PAGE_IO + 0x014)
#define HI6403_GPIO9_EN_BIT             3
#define HI6403_I2S1_SDI_EN_BIT          0
#define HI6403_I2S1_SDO_IOSHARE_REG     (BASE_ADDR_PAGE_IO + 0x018)
#define HI6403_IOTEST2_EN_BIT           4
#define HI6403_GPIO10_EN_BIT            3
#define HI6403_I2S1_SDO_EN_BIT          0
#define HI6403_I2S2_SYNC_IOSHARE_REG    (BASE_ADDR_PAGE_IO + 0x01C)
#define HI6403_IOTEST3_EN_BIT           4
#define HI6403_GPIO11_EN_BIT            3
#define HI6403_I2S2_SYNC_EN_BIT         0
#define HI6403_I2S2_CLK_IOSHARE_REG     (BASE_ADDR_PAGE_IO + 0x020)
#define HI6403_IOTEST4_EN_BIT           4
#define HI6403_GPIO12_EN_BIT            3
#define HI6403_I2S2_CLK_EN_BIT          0
#define HI6403_I2S2_SDI_IOSHARE_REG     (BASE_ADDR_PAGE_IO + 0x024)
#define HI6403_IOTEST5_EN_BIT           4
#define HI6403_GPIO13_EN_BIT            3
#define HI6403_I2S2_SDI_EN_BIT          0
#define HI6403_I2S2_SDO_IOSHARE_REG     (BASE_ADDR_PAGE_IO + 0x028)
#define HI6403_IOTEST6_EN_BIT           4
#define HI6403_GPIO14_EN_BIT            3
#define HI6403_I2S2_SDO_EN_BIT          0
#define HI6403_I2S3_SYNC_IOSHARE_REG    (BASE_ADDR_PAGE_IO + 0x02C)
#define HI6403_IOTEST7_EN_BIT           4
#define HI6403_GPIO15_EN_BIT            3
#define HI6403_I2S3_SYNC_EN_BIT         0
#define HI6403_I2S3_CLK_IOSHARE_REG     (BASE_ADDR_PAGE_IO + 0x030)
#define HI6403_IOTEST8_EN_BIT           4
#define HI6403_GPIO16_EN_BIT            3
#define HI6403_DSD_CLK_EN_BIT           2
#define HI6403_I2S3_CLK_EN_BIT          0
#define HI6403_I2S3_SDI_IOSHARE_REG     (BASE_ADDR_PAGE_IO + 0x034)
#define HI6403_IOTEST9_EN_BIT           4
#define HI6403_GPIO17_EN_BIT            3
#define HI6403_DSD_L_EN_BIT             2
#define HI6403_I2S3_SDI_EN_BIT          0
#define HI6403_I2S3_SDO_IOSHARE_REG     (BASE_ADDR_PAGE_IO + 0x038)
#define HI6403_IOTEST10_EN_BIT          4
#define HI6403_GPIO18_EN_BIT            3
#define HI6403_DSD_R_EN_BIT             2
#define HI6403_I2S3_SDO_EN_BIT          0
#define HI6403_I2S4_SYNC_IOSHARE_REG    (BASE_ADDR_PAGE_IO + 0x03C)
#define HI6403_IOTEST11_EN_BIT          4
#define HI6403_GPIO19_EN_BIT            3
#define HI6403_I2S4_SYNC_EN_BIT         0
#define HI6403_I2S4_CLK_IOSHARE_REG     (BASE_ADDR_PAGE_IO + 0x040)
#define HI6403_IOTEST12_EN_BIT          4
#define HI6403_GPIO20_EN_BIT            3
#define HI6403_I2S4_CLK_EN_BIT          0
#define HI6403_I2S4_SDI_IOSHARE_REG     (BASE_ADDR_PAGE_IO + 0x044)
#define HI6403_IOTEST13_EN_BIT          4
#define HI6403_GPIO21_EN_BIT            3
#define HI6403_I2S4_SDI_EN_BIT          0
#define HI6403_I2S4_SDO_IOSHARE_REG     (BASE_ADDR_PAGE_IO + 0x048)
#define HI6403_IOTEST14_EN_BIT          4
#define HI6403_GPIO21_EN_BIT            3
#define HI6403_I2S4_SDO_EN_BIT          0
#define HI6403_DMIC0_CLK_IOSHARE_REG    (BASE_ADDR_PAGE_IO + 0x04C)
#define HI6403_IOTEST15_EN_BIT          4
#define HI6403_GPIO1_EN_BIT             3
#define HI6403_DMIC0_CLK_EN_BIT         0
#define HI6403_DMIC0_DATA_IOSHARE_REG   (BASE_ADDR_PAGE_IO + 0x050)
#define HI6403_IOTEST16_EN_BIT          4
#define HI6403_GPIO2_EN_BIT             3
#define HI6403_DMIC0_DATA_EN_BIT        0
#define HI6403_DMIC1_CLK_IOSHARE_REG    (BASE_ADDR_PAGE_IO + 0x054)
#define HI6403_IOTEST17_EN_BIT          4
#define HI6403_GPIO3_EN_BIT             3
#define HI6403_DMIC1_CLK_EN_BIT         0
#define HI6403_DMIC1_DATA_IOSHARE_REG   (BASE_ADDR_PAGE_IO + 0x058)
#define HI6403_IOTEST18_EN_BIT          4
#define HI6403_GPIO4_EN_BIT             3
#define HI6403_DMIC1_DATA_EN_BIT        0
#define HI6403_GPIO0_IOCONFIG_REG       (BASE_ADDR_PAGE_IO + 0x210)
#define HI6403_SSI_DATA_IOS_IOM_CTRL    (BASE_ADDR_PAGE_IO + 0x214)
#define HI6403_IRQN_IOCONFIG_REG        (BASE_ADDR_PAGE_IO + 0x218)
#define HI6403_SLIM_DATA_IOCONFIG_REG   (BASE_ADDR_PAGE_IO + 0x21C)
#define HI6403_SLIM_DATA_IO_CURRENT_BIT 2
#define HI6403_SLIM_CLK_IOCONFIG_REG    (BASE_ADDR_PAGE_IO + 0x220)
#define HI6403_SLIM_CLK_IO_CURRENT_BIT  2
#define HI6403_SLIM_SCHMITT_BIT         0
#define HI6403_I2S2_SDO_IOCONFIG_REG    (BASE_ADDR_PAGE_IO + 0x238)
#define HI6403_I2S4_SDO_IOCONFIG_REG    (BASE_ADDR_PAGE_IO + 0x258)
#define HI6403_I2S_SDO_INPUT_EN_BIT     8
#define HI6403_I2S_SDO_OUTPUT_EN_BIT    7
#define HI6403_SPK_CLK_IOCONFIG_REG     (BASE_ADDR_PAGE_IO + 0x26C)
#define HI6403_12M288_IOCONFIG_REG      (BASE_ADDR_PAGE_IO + 0x274)
/* io reg end */

/* ana reg begin */
#define HI6403_PATH_CLK_SEL_REG         (BASE_ADDR_PAGE_ANA + 0x010)
#define HI6403_ANALOG_REG0              (BASE_ADDR_PAGE_ANA + 0x000)
#define HI6403_IBIAS_PD_BIT             7
#define HI6403_BG_PD_BIT                6
#define HI6403_PTAT_PD_BIT              5
#define HI6403_PD_OTP_BIT               4
#define HI6403_VREFSEL_BIT              2
#define HI6403_VREF_FAST_BIT            1
#define HI6403_VREF_MUX_BIT             0

#define HI6403_ANALOG_REG1              (BASE_ADDR_PAGE_ANA + 0x001)
#define HI6403_MAIN_PGA_PD_BIT          7
#define HI6403_AUX_PGA_PD_BIT           6
#define HI6403_LINEINL_PGA_PD_BIT       5
#define HI6403_LINEINR_PGA_PD_BIT       4
#define HI6403_ADC0L_PD_BIT             3
#define HI6403_ADC0R_PD_BIT             2
#define HI6403_ADC1L_PD_BIT             1
#define HI6403_ADC1R_PD_BIT             0

#define HI6403_ANALOG_REG2              (BASE_ADDR_PAGE_ANA + 0x002)
#define HI6403_HP_GEN_PD_BIT            6
#define HI6403_DAC_HPR_PD_BIT           5
#define HI6403_DAC_HPL_PD_BIT           4
#define HI6403_DAC_HP_VB_PB_BIT         3
#define HI6403_DAC_HP_VB_SEC_PB_BIT     2
#define HI6403_DAC_HPR_MUTE_BIT         1
#define HI6403_DAC_HPL_MUTE_BIT         0

#define HI6403_ANALOG_REG3              (BASE_ADDR_PAGE_ANA + 0x003)
#define HI6403_HPL_PD_BIT               4
#define HI6403_HPR_PD_BIT               3
#define HI6403_HPL_FD_PD_BIT            2
#define HI6403_HPR_FD_PD_BIT            1
#define HI6403_HP_RDET_PD_BIT           0

#define HI6403_ANALOG_REG4              (BASE_ADDR_PAGE_ANA + 0x004)
#define HI6403_DAC_EAR_PD_BIT           5
#define HI6403_DAC_LOL_PD_BIT           4
#define HI6403_DAC_LOR_PD_BIT           3
#define HI6403_LOL_PD_BIT               2
#define HI6403_LOR_PD_BIT               1
#define HI6403_EAR_PD_BIT               0

#define HI6403_ANALOG_REG5              (BASE_ADDR_PAGE_ANA + 0x005)
#define HI6403_ANALOG_REG6              (BASE_ADDR_PAGE_ANA + 0x006)
#define HI6403_ANALOG_REG7              (BASE_ADDR_PAGE_ANA + 0x007)
#define HI6403_ANALOG_REG8              (BASE_ADDR_PAGE_ANA + 0x008)
#define HI6403_ANALOG_REG9              (BASE_ADDR_PAGE_ANA + 0x009)
#define HI6403_ANALOG_REG10             (BASE_ADDR_PAGE_ANA + 0x00A)
#define HI6403_ANALOG_REG11             (BASE_ADDR_PAGE_ANA + 0x00B)

#define HI6403_ANALOG_REG13             (BASE_ADDR_PAGE_ANA + 0x00D)
#define HI6403_DAC_CHOP_CLK_SEL_BIT     2

#define HI6403_ANALOG_REG14             (BASE_ADDR_PAGE_ANA + 0x00E)
#define HI6403_CHOPPER_BIT              1
#define HI6403_ANALOG_REG15             (BASE_ADDR_PAGE_ANA + 0x00F)
#define HI6403_TXCHOP_BPS_BIT           5
#define HI6403_DAC_LOUT_CHOP_BPS_BIT    4
#define HI6403_LI_CHOP_BPS_BIT          3
#define HI6403_MADPGA_CHOP_BPS_BIT      2
#define HI6403_TX_DAC_CLK_BPS_BIT       1
#define HI6403_POP_CLK_PD_BIT           0

#define HI6403_ANALOG_REG20             (BASE_ADDR_PAGE_ANA + 0x014)
#define HI6403_LINEINL_SEL_BIT          6
#define HI6403_LINEINL_PGA_GAIN_BIT     1
#define HI6403_LINEINL_MUTE2_BIT        0

#define HI6403_ANALOG_REG21             (BASE_ADDR_PAGE_ANA + 0x015)
#define HI6403_LINEINR_SEL_BIT          6
#define HI6403_LINEINR_PGA_GAIN_BIT     1
#define HI6403_LINEINR_MUTE2_BIT        0

#define HI6403_ANALOG_REG22             (BASE_ADDR_PAGE_ANA + 0x016)
#define HI6403_AUX_PGA_GAIN_BIT         3
#define HI6403_AUX_MUTE1_BIT            2
#define HI6403_AUX_MUTE2_BIT            1

#define HI6403_ANALOG_REG23             (BASE_ADDR_PAGE_ANA + 0x017)
#define HI6403_MAIN_PGA_GAIN_BIT        2
#define HI6403_MAINMIC_SEL_BIT          1
#define HI6403_MAIN_MUTE2_BIT           0

#define HI6403_ANALOG_REG24             (BASE_ADDR_PAGE_ANA + 0x018)
#define HI6403_LINEINL_MUTE1_BIT        5
#define HI6403_LINEINR_MUTE1_BIT        3
#define HI6403_MAIN_MUTE1_BIT           1

#define HI6403_ANALOG_REG30             (BASE_ADDR_PAGE_ANA + 0x01E)

#define HI6403_ANALOG_REG31             (BASE_ADDR_PAGE_ANA + 0x01F)
#define HI6403_ADC0L_BOOST_1_BIT        4
#define HI6403_ADC0R_BOOST_1_BIT        0

#define HI6403_ANALOG_REG32             (BASE_ADDR_PAGE_ANA + 0x020)
#define HI6403_ANALOG_REG33             (BASE_ADDR_PAGE_ANA + 0x021)

#define HI6403_ANALOG_REG34             (BASE_ADDR_PAGE_ANA + 0x022)
#define HI6403_ADC1L_BOOST_1_BIT        4
#define HI6403_ADC1R_BOOST_1_BIT        0

#define HI6403_ANALOG_REG35             (BASE_ADDR_PAGE_ANA + 0x023)

#define HI6403_ANALOG_REG36             (BASE_ADDR_PAGE_ANA + 0x024)
#define HI6403_ADC0L_BOOST_2_BIT        3
#define HI6403_ADC0R_BOOST_2_BIT        2
#define HI6403_ADC1L_BOOST_2_BIT        1
#define HI6403_ADC1R_BOOST_2_BIT        0

#define HI6403_ANALOG_REG38             (BASE_ADDR_PAGE_ANA + 0x026)
#define HI6403_DAC_HP_VBR_SEL_BIT       4
#define HI6403_HP_RES_CT_BIT            0

#define HI6403_ANALOG_REG39             (BASE_ADDR_PAGE_ANA + 0x027)
#define HI6403_DAC_HP_PLAN_SEL_BIT      2
#define HI6403_DAC_HP_PLANA_HVR_SEL_BIT 1
#define HI6403_DAC_HP_VBSWEN_BIT        0

#define HI6403_ANALOG_REG40             (BASE_ADDR_PAGE_ANA + 0x028)
#define HI6403_DAC_HPL_HI_CELLOFF_EN    1
#define HI6403_DAC_HPR_HI_CELLOFF_EN    0

#define HI6403_ANALOG_REG43             (BASE_ADDR_PAGE_ANA + 0x02B)
#define HI6403_HSD_IRQ_LINK_DIS_BIT     7
#define HI6403_HPL_POP_PULL_5_3_BIT     3
#define HI6403_HPL_POP_PULL_2_0_BIT     0

#define HI6403_ANALOG_REG44             (BASE_ADDR_PAGE_ANA + 0x02C)
#define HI6403_HPR_POP_PULL_5_3_BIT     3
#define HI6403_HPR_POP_PULL_2_0_BIT     0

#define HI6403_HPL_POP_CFG_REG          (BASE_ADDR_PAGE_ANA + 0x02D)
#define HI6403_HPR_POP_CFG_REG          (BASE_ADDR_PAGE_ANA + 0x02E)

#define HI6403_ANALOG_REG47             (BASE_ADDR_PAGE_ANA + 0x02F)
#define HI6403_HP_POP_RST_BIT           4
#define HI6403_HP_POP_AUTO_EN_BIT       3
#define HI6403_HP_POP_RAMP_FAST_BIT     2
#define HI6403_HP_POP_RAMP_SPD_CFG_BIT  0

#define HI6403_ANALOG_REG48             (BASE_ADDR_PAGE_ANA + 0x030)
#define HI6403_HP_GND_CTR_BIT           7
#define HI6403_HP_SRB_CTRL_BIT          6
#define HI6403_HP_IBCT_BIT              4
#define HI6403_HP_FB_EN_BIT             3
#define HI6403_HP_FB_STB_CTRL_BIT       2
#define HI6403_HP_FB_IBCT_BIT           0

#define HI6403_ANALOG_REG49             (BASE_ADDR_PAGE_ANA + 0x031)
#define HI6403_HP_FB_RES_CT_BIT         0

#define HI6403_ANALOG_REG50             (BASE_ADDR_PAGE_ANA + 0x032)
#define HI6403_DETRES_SEL_BIT           4
#define HI6403_DETRES_CHAIN_SEL_BIT     1
#define HI6403_DETRES_RST_BIT           0

#define HI6403_ANALOG_REG52             (BASE_ADDR_PAGE_ANA + 0x034)

#define HI6403_ANALOG_REG62             (BASE_ADDR_PAGE_ANA + 0x03E)
#define HI6403_EAR_CM_CTL_BIT           6
#define HI6403_EAR_GAIN_BIT             1
#define HI6403_EAR_MUTE_BIT             0

#define HI6403_ANALOG_REG63             (BASE_ADDR_PAGE_ANA + 0x03F)
#define HI6403_LOL_CM_CTL_BIT           6
#define HI6403_LOL_GAIN_BIT             1
#define HI6403_LOL_MUTE_BIT             0

#define HI6403_ANALOG_REG64             (BASE_ADDR_PAGE_ANA + 0x040)
#define HI6403_LOR_CM_CTL_BIT           6
#define HI6403_LOR_GAIN_BIT             1
#define HI6403_LOR_MUTE_BIT             0

#define HI6403_ANALOG_REG65             (BASE_ADDR_PAGE_ANA + 0x041)
#define HI6403_ADC_MUTE_ZCEN_BIT        4
#define HI6403_DAC_MUTE_ZCEN_BIT        3
#define HI6403_LOR_ZCEN_BIT             2
#define HI6403_LOL_ZCEN_BIT             1
#define HI6403_EAR_ZCEN_BIT             0

#define HI6403_ANALOG_REG70             (BASE_ADDR_PAGE_ANA + 0x46)
#define HI6403_ANALOG_REG71             (BASE_ADDR_PAGE_ANA + 0x47)
#define HI6403_ANALOG_REG72             (BASE_ADDR_PAGE_ANA + 0x48)

#define HI6403_ANALOG_REG73             (BASE_ADDR_PAGE_ANA + 0x49)
#define HI6403_IB05_HP_BIT              4
#define HI6403_IB05_HP_FB_BIT           0

#define HI6403_ANALOG_REG74             (BASE_ADDR_PAGE_ANA + 0x4A)
#define HI6403_ANALOG_REG75             (BASE_ADDR_PAGE_ANA + 0x4B)
#define HI6403_ANALOG_REG76             (BASE_ADDR_PAGE_ANA + 0x4C)

#define HI6403_ANALOG_REG77             (BASE_ADDR_PAGE_ANA + 0x4D)
#define HI6403_IB05_DAC_HP_BIT          4
#define HI6403_IB05_OTHER_BIT           0

#define HI6403_ANALOG_REG78             (BASE_ADDR_PAGE_ANA + 0x4E)
#define HI6403_ANALOG_REG79             (BASE_ADDR_PAGE_ANA + 0x4F)
#define HI6403_CODEC_ANA_RWREG_80       (BASE_ADDR_PAGE_ANA + 0x50)
#define HI6403_ANALOG_REG81             (BASE_ADDR_PAGE_ANA + 0x51)

#define HI6403_ANALOG_REG82             (BASE_ADDR_PAGE_ANA + 0x52)
#define HI6403_HP_IBIAS_EN_BIT          1

#define HI6403_ANALOG_REG83             (BASE_ADDR_PAGE_ANA + 0x53)
#define HI6403_MAD_MIC4_SEL_BIT         7
#define HI6403_MAD_MIC3_SEL_BIT         6
#define HI6403_MAD_AUXMIC_SEL_BIT       5
#define HI6403_MAD_MAINMIC_SEL_BIT      4
#define HI6403_MAD_PGA_PD_BIT           1
#define HI6403_MAD_ADC_PD_BIT           0

#define HI6403_ANALOG_REG84             (BASE_ADDR_PAGE_ANA + 0x54)
#define HI6403_MAD_PGA_GAIN_BIT         3
#define HI6403_MAD_MUTE1_BIT            2
#define HI6403_MAD_MUTE2_BIT            1
#define HI6403_MAD_HPMIC_SEL_BIT        0

#define HI6403_ANALOG_REG088            (BASE_ADDR_PAGE_ANA + 0x058)
#define HI6403_ADC_MAD_BOOST_2_BIT      5
#define HI6403_ADC_MAD_BOOST_1_BIT      0

#define HI6403_ANALOG_REG089            (BASE_ADDR_PAGE_ANA + 0x059)
#define HI6403_HSMIC_PD_BIT             7
#define HI6403_MBHD_SAR_PD_BIT          6
#define HI6403_SARADC_START_BIT         5
#define HI6403_MBHD_COMP_PD_BIT         4
#define HI6403_MIC4_PD_BIT              3
#define HI6403_MIC3_PD_BIT              2
#define HI6403_AUXMIC_PD_BIT            1
#define HI6403_MAINMIC_PD_BIT           0

#define HI6403_HP_DET_CFG_REG           (BASE_ADDR_PAGE_ANA + 0x05A)
#define HI6403_SAR_INPUT_SEL_BIT        6
#define HI6403_SAR_REF_SEL_BIT          3

#define HI6403_SAR_CONFIG_REG           (BASE_ADDR_PAGE_ANA + 0x05B)
#define HI6403_SAR_CLK_SEL_BIT          5
#define HI6403_SAR_RST_BIT              4

#define HI6403_MBHD_COMP_CFG_REG        (BASE_ADDR_PAGE_ANA + 0x05C)

#define HI6403_ANALOG_REG093            (BASE_ADDR_PAGE_ANA + 0x05D)
#define HI6403_HSMIC_DISCHG_EN_BIT      5
#define HI6403_MAINMIC_DISCHG_EN_BIT    4
#define HI6403_AUXMIC_DISCHG_EN_BIT     3
#define HI6403_MIC3_DISCHG_EN_BIT       2
#define HI6403_MIC4_DISCHG_EN_BIT       1
#define HI6403_HS_ECO_EN_BIT            0

#define HI6403_MIC_3_4_CONFIG_REG       (BASE_ADDR_PAGE_ANA + 0x05E)
#define HI6403_MIC_1_2_CONFIG_REG       (BASE_ADDR_PAGE_ANA + 0x05F)
#define HI6403_HSMIC_CONFIG_REG         (BASE_ADDR_PAGE_ANA + 0x060)

#define HI6403_ANALOG_REG97             (BASE_ADDR_PAGE_ANA + 0x061)
#define HI6403_ISO_A18_BIT              1
#define HI6403_ISO_A33_BIT              0

#define HI6403_ANALOG_REG98             (BASE_ADDR_PAGE_ANA + 0x062)
#define HI6403_HSD_SEL_BIT              5
#define HI6403_HSD_VTH_SEL_BIT          3
#define HI6403_HSD_DIR_SEL_BIT          2

#define HI6403_CODEC_ANA_RWREG_99       (BASE_ADDR_PAGE_ANA + 0x063)
#define HI6403_CODEC_ANA_RWREG_100      (BASE_ADDR_PAGE_ANA + 0x064)
#define HI6403_CODEC_ANA_RWREG_101      (BASE_ADDR_PAGE_ANA + 0x065)
#define HI6403_CODEC_ANA_RWREG_102      (BASE_ADDR_PAGE_ANA + 0x066)

#define HI6403_CODEC_ANA_RWREG_106      (BASE_ADDR_PAGE_ANA + 0x06A)
#define HI6403_CODEC_ANA_RWREG_106_OCP_BIT 6
#define HI6403_CODEC_ANA_RWREG_107      (BASE_ADDR_PAGE_ANA + 0x06B)
#define HI6403_BUCK1_REG_R              0

#define HI6403_ANALOG_REG108            (BASE_ADDR_PAGE_ANA + 0x06C)
#define HI6403_BUCK1_DOWN_TIME_BIT      4
#define HI6403_CP1_EN_SEL_BIT           3
#define HI6403_CP1_EN_CTL_BIT           2
#define HI6403_BUCK1_PSL_TIME_BIT       0

#define HI6403_CODEC_ANA_RWREG_109      (BASE_ADDR_PAGE_ANA + 0x06D)

#define HI6403_ANALOG_REG111            (BASE_ADDR_PAGE_ANA + 0x06F)

#define HI6403_CODEC_ANA_RWREG_113      (BASE_ADDR_PAGE_ANA + 0x071)
#define HI6403_CODEC_ANA_RWREG_114      (BASE_ADDR_PAGE_ANA + 0x072)
#define HI6403_CODEC_ANA_RWREG_115      (BASE_ADDR_PAGE_ANA + 0x073)
#define HI6403_CODEC_ANA_RWREG_116      (BASE_ADDR_PAGE_ANA + 0x074)
#define HI6403_CODEC_ANA_RWREG_119      (BASE_ADDR_PAGE_ANA + 0x077)

#define HI6403_ANALOG_REG121            (BASE_ADDR_PAGE_ANA + 0x079)
#define HI6403_BUCK2_DOWN_TIME_BIT      4
#define HI6403_CP2_EN_SEL_BIT           3
#define HI6403_CP2_EN_CTL_BIT           2
#define HI6403_BUCK2_PSL_TIME_BIT       0

#define HI6403_ANALOG_REG129            (BASE_ADDR_PAGE_ANA + 0x081)
#define HI6403_BUCK2_ENP_BIT            1
#define HI6403_BUCK1_ENP_BIT            0

#define HI6403_ANALOG_REG130            (BASE_ADDR_PAGE_ANA + 0x082)
#define HI6403_BUCK2_PD_SINGLE_BIT      1
#define HI6403_BUCK1_PD_SINGLE_BIT      0

#define HI6403_CODEC_ANA_RWREG_132      (BASE_ADDR_PAGE_ANA + 0x084)
#define HI6403_CODEC_ANA_RWREG_133      (BASE_ADDR_PAGE_ANA + 0x085)
#define HI6403_CODEC_ANA_RWREG_134      (BASE_ADDR_PAGE_ANA + 0x086)
#define HI6403_CODEC_ANA_RWREG_135      (BASE_ADDR_PAGE_ANA + 0x087)
#define HI6403_CODEC_ANA_RWREG_136      (BASE_ADDR_PAGE_ANA + 0x088)
#define HI6403_CODEC_ANA_RWREG_137      (BASE_ADDR_PAGE_ANA + 0x089)
#define HI6403_CODEC_ANA_RWREG_138      (BASE_ADDR_PAGE_ANA + 0x08A)
#define HI6403_CODEC_ANA_RWREG_139      (BASE_ADDR_PAGE_ANA + 0x08B)
#define HI6403_CODEC_ANA_RWREG_140      (BASE_ADDR_PAGE_ANA + 0x08C)
#define HI6403_CODEC_ANA_RWREG_141      (BASE_ADDR_PAGE_ANA + 0x08D)
#define HI6403_CODEC_ANA_RWREG_142      (BASE_ADDR_PAGE_ANA + 0x08E)
#define HI6403_CODEC_ANA_RWREG_143      (BASE_ADDR_PAGE_ANA + 0x08F)
#define HI6403_CODEC_ANA_RWREG_144      (BASE_ADDR_PAGE_ANA + 0x090)
#define HI6403_CODEC_ANA_RWREG_145      (BASE_ADDR_PAGE_ANA + 0x091)
#define HI6403_CODEC_ANA_RWREG_146      (BASE_ADDR_PAGE_ANA + 0x092)
#define HI6403_CODEC_ANA_RWREG_147      (BASE_ADDR_PAGE_ANA + 0x093)
#define HI6403_CODEC_ANA_RWREG_148      (BASE_ADDR_PAGE_ANA + 0x094)
#define HI6403_MAIN1_PLL_CFG_REG1       (BASE_ADDR_PAGE_ANA + 0x095)
#define HI6403_MAIN1_ISO_18_BIT         5
#define HI6403_MAIN1_ISO_12_BIT         4
#define HI6403_MAIN1_PLL_PD_BIT         3
#define HI6403_MAIN1_PLL_BYPASS_BIT     2
#define HI6403_MAIN1_PLL_RST_BIT        1
#define HI6403_MAIN1_PLL_RUN_START_BIT  0

#define HI6403_MAIN1_PLL_CFG_REG2       (BASE_ADDR_PAGE_ANA + 0x096)
#define HI6403_MAIN1_PLL_DIV_REG        (BASE_ADDR_PAGE_ANA + 0x097)
#define HI6403_MAIN1_PLL_CFG_REG3       (BASE_ADDR_PAGE_ANA + 0x098)
#define HI6403_MAIN1_PLL_WORD_REG1      (BASE_ADDR_PAGE_ANA + 0x099)
#define HI6403_MAIN1_PLL_WORF_REG2      (BASE_ADDR_PAGE_ANA + 0x09A)
#define HI6403_MAIN1_PLL_FILTER_REG     (BASE_ADDR_PAGE_ANA + 0x09B)
#define HI6403_MAIN1_PLL_CFG_REG4       (BASE_ADDR_PAGE_ANA + 0x09C)
#define HI6403_MAIN1_PLL_CFG_REG5       (BASE_ADDR_PAGE_ANA + 0x09D)
#define HI6403_MAIN1_PLL_CFG_REG6       (BASE_ADDR_PAGE_ANA + 0x09E)
#define HI6403_MAIN1_PLL_TRACK_REG1     (BASE_ADDR_PAGE_ANA + 0x09F)
#define HI6403_MAIN1_PLL_TRACK_REG2     (BASE_ADDR_PAGE_ANA + 0x0A0)
#define HI6403_MAIN1_PLL_TRACK_REG3     (BASE_ADDR_PAGE_ANA + 0x0A1)
#define HI6403_MAIN1_PLL_CFG_REG7       (BASE_ADDR_PAGE_ANA + 0x0A2)
#define HI6403_MAIN1_PLL_CFG_REG8       (BASE_ADDR_PAGE_ANA + 0x0A3)
#define HI6403_MAIN1_PLL_CFG_REG9       (BASE_ADDR_PAGE_ANA + 0x0A4)
#define HI6403_MAIN1_PLL_LOCK_CFG_REG   (BASE_ADDR_PAGE_ANA + 0x0A5)
#define HI6403_MAIN1_PLL_PHASE_CFG_REG  (BASE_ADDR_PAGE_ANA + 0x0A6)

#define HI6403_MAIN2_PLL_CFG_REG1       (BASE_ADDR_PAGE_ANA + 0x0A7)
#define HI6403_MAIN2_ISO_18_BIT         5
#define HI6403_MAIN2_ISO_12_BIT         4
#define HI6403_MAIN2_PLL_PD_BIT         3
#define HI6403_MAIN2_PLL_BYPASS_BIT     2
#define HI6403_MAIN2_PLL_RST_BIT        1
#define HI6403_MAIN2_PLL_RUN_START_BIT  0

#define HI6403_MAIN2_PLL_CFG_REG2       (BASE_ADDR_PAGE_ANA + 0x0A8)
#define HI6403_MAIN2_PLL_DIV_REG        (BASE_ADDR_PAGE_ANA + 0x0A9)
#define HI6403_MAIN2_PLL_CFG_REG3       (BASE_ADDR_PAGE_ANA + 0x0AA)
#define HI6403_MAIN2_PLL_WORD_REG1      (BASE_ADDR_PAGE_ANA + 0x0AB)
#define HI6403_MAIN2_PLL_WORF_REG2      (BASE_ADDR_PAGE_ANA + 0x0AC)
#define HI6403_MAIN2_PLL_FILTER_REG     (BASE_ADDR_PAGE_ANA + 0x0AD)
#define HI6403_MAIN2_PLL_CFG_REG4       (BASE_ADDR_PAGE_ANA + 0x0AE)
#define HI6403_MAIN2_PLL_CFG_REG5       (BASE_ADDR_PAGE_ANA + 0x0AF)
#define HI6403_MAIN2_PLL_CFG_REG6       (BASE_ADDR_PAGE_ANA + 0x0B0)
#define HI6403_MAIN2_PLL_TRACK_REG1     (BASE_ADDR_PAGE_ANA + 0x0B1)
#define HI6403_MAIN2_PLL_TRACK_REG2     (BASE_ADDR_PAGE_ANA + 0x0B2)
#define HI6403_MAIN2_PLL_TRACK_REG3     (BASE_ADDR_PAGE_ANA + 0x0B3)
#define HI6403_MAIN2_PLL_CFG_REG7       (BASE_ADDR_PAGE_ANA + 0x0B4)
#define HI6403_MAIN2_PLL_CFG_REG8       (BASE_ADDR_PAGE_ANA + 0x0B5)
#define HI6403_MAIN2_PLL_CFG_REG9       (BASE_ADDR_PAGE_ANA + 0x0B6)
#define HI6403_MAIN2_PLL_LOCK_CFG_REG   (BASE_ADDR_PAGE_ANA + 0x0B7)
#define HI6403_MAIN2_PLL_PHASE_CFG_REG  (BASE_ADDR_PAGE_ANA + 0x0B8)

#define HI6403_MAD_PLL_CFG_REG9         (BASE_ADDR_PAGE_ANA + 0x0B9)
#define HI6403_MAD_PLL_SEL_OSC_BIT      7
#define HI6403_MAD_PLL_DCO_EN_BIT       6
#define HI6403_MAD_PLL_DIG_EN_BIT       5
#define HI6403_MAD_PLL_ANA_EN_BIT       4
#define HI6403_MAD_PLL_PD_BIT           3
#define HI6403_MAD_PLL_BYPASS_BIT       2
#define HI6403_MAD_PLL_RST_BIT          1
#define HI6403_MAD_PLL_RUN_START_BIT    0

#define HI6403_MAD_PLL_CFG_REG10        (BASE_ADDR_PAGE_ANA + 0x0BA)
#define HI6403_MAD_PLL_WORD_REG1        (BASE_ADDR_PAGE_ANA + 0x0BB)
#define HI6403_MAD_PLL_WORF_REG2        (BASE_ADDR_PAGE_ANA + 0x0BC)
#define HI6403_MAD_PLL_CFG_REG1         (BASE_ADDR_PAGE_ANA + 0x0BD)
#define HI6403_MAD_PLL_CFG_REG2         (BASE_ADDR_PAGE_ANA + 0x0BE)
#define HI6403_MAD_PLL_CFG_REG3         (BASE_ADDR_PAGE_ANA + 0x0BF)
#define HI6403_MAD_PLL_CFG_REG4         (BASE_ADDR_PAGE_ANA + 0x0C0)
#define HI6403_MAD_PLL_CFG_REG5         (BASE_ADDR_PAGE_ANA + 0x0C1)
#define HI6403_MAD_PLL_LOCK_CFG_REG     (BASE_ADDR_PAGE_ANA + 0x0C2)
#define HI6403_MAD_PLL_CFG_REG6         (BASE_ADDR_PAGE_ANA + 0x0C3)
#define HI6403_MAD_PLL_ISO_18_BIT       2
#define HI6403_MAD_PLL_TEST_RDY_BIT     1

#define HI6403_ANALOG_REG195            (BASE_ADDR_PAGE_ANA + 0x0C3)
#define HI6403_PLL_IBIAS_GEN_BIT        0
#define HI6403_ANALOG_REG196            (BASE_ADDR_PAGE_ANA + 0x0C4)
#define HI6403_ANALOG_REG197            (BASE_ADDR_PAGE_ANA + 0x0C5)
#define HI6403_ANALOG_REG198            (BASE_ADDR_PAGE_ANA + 0x0C6)

#define HI6403_ANALOG_REG199            (BASE_ADDR_PAGE_ANA + 0x0C7)
#define HI6403_BUCK_CLK_SEL_BIT         5
#define HI6403_CLK_96K_PD_BIT           4
#define HI6403_BUCK1_CLK_PD_BIT         3
#define HI6403_BUCK2_CLK_PD_BIT         2
#define HI6403_CP1_CLK_PD_BIT           1
#define HI6403_CP2_CLK_PD_BIT           0

#define HI6403_ANALOG_REG200            (BASE_ADDR_PAGE_ANA + 0x0C8)

#define HI6403_SAR_VALUE_REG            (BASE_ADDR_PAGE_ANA + 0x0CD)

#define HI6403_EC_VERSION_REG          (BASE_ADDR_PAGE_ANA + 0x0D3)

/* ana reg end */

/* dig reg begin */
/* DACL FLT MIXER GAIN CFG */
#define HI6403_DACL_FLT_MIXER_GAIN_CFG_REG  (BASE_ADDR_PAGE_DIG + 0x217)
#define HI6403_DACL_FLT_MIXER_GAIN_2_BIT    2
#define HI6403_DACL_FLT_MIXER_GAIN_1_BIT    0

/* DACR FLT MIXER GAIN CFG */
#define HI6403_DACR_FLT_MIXER_GAIN_CFG_REG  (BASE_ADDR_PAGE_DIG + 0x21A)
#define HI6403_DACR_FLT_MIXER_GAIN_2_BIT    2
#define HI6403_DACR_FLT_MIXER_GAIN_1_BIT    0

#define HI6403_DIG_PGA_FADE_MODE_CFG_REG    (BASE_ADDR_PAGE_DIG + 0x1DD)

#define HI6403_DACSL_PGA_GAIN_CFG_REG      (BASE_ADDR_PAGE_DIG + 0x1FD)

/* CLASS H */
#define HI6403_CLASS_H_CFG_REG0            (BASE_ADDR_PAGE_DIG + 0x302)
#define HI6403_CLASS_H_CFG_REG1            (BASE_ADDR_PAGE_DIG + 0x306)
#define HI6403_CLASS_H_SEL_BIT             7

/* CLASSH_HP_EP_CTRL */
#define HI6403_CLASSH_HP_EP_CTRL           (BASE_ADDR_PAGE_DIG + 0x3A8)
#define HI6403_DACL_S_UP16_DIN_SEL_BIT     6
#define HI6403_DACR_U16_MUX_BIT            5
#define HI6403_DACL_U16_MUX_BIT            4
#define HI6403_CLASSH_DIN_R_SEL_BIT        2
#define HI6403_CLASSH_DIN_L_SEL_BIT        0

#define HI6403_CLASSH_SYNC_CTRL_REG        (BASE_ADDR_PAGE_DIG + 0x3A9)
#define HI6403_CLASSH_SYNC_CTRL_BIT        0

/* CLASSH_CTRL */
#define HI6403_CLASSH_CTRL12               (BASE_ADDR_PAGE_DIG + 0x30C)
#define HI6403_CLASSH_HP_EP_SW_BIT         7
#define HI6403_CLASSH_FALL_DLY_EN_BIT      6

#define HI6403_CLASSH_CTRL4                (BASE_ADDR_PAGE_DIG + 0x304)
#define HI6403_CLASSH_SELD_BIT             7

/* MUX REG */
/* MUX OF DAC SRC IN */
#define HI6403_DAC_SRC_MUX_SEL             (BASE_ADDR_PAGE_DIG + 0x015)
#define HI6403_DACR_SRC_MUX_BIT            7
#define HI6403_DACL_SRC_MUX_BIT            3

#define HI6403_HPL_SDM_NEW_CTRL0_REG       (BASE_ADDR_PAGE_DIG + 0x12D)
#define HI6403_HPL_SDM_NEW_CTRL1_REG       (BASE_ADDR_PAGE_DIG + 0x12E)
#define HI6403_HPL_SDM_NEW_CTRL2_REG       (BASE_ADDR_PAGE_DIG + 0x12F)
#define HI6403_HPL_SDM_NEW_CTRL3_REG       (BASE_ADDR_PAGE_DIG + 0x130)
#define HI6403_HPL_SDM_NEW_CTRL4_REG       (BASE_ADDR_PAGE_DIG + 0x131)
#define HI6403_HPL_SDM_NEW_CTRL5_REG       (BASE_ADDR_PAGE_DIG + 0x132)
#define HI6403_HPR_SDM_NEW_CTRL0_REG       (BASE_ADDR_PAGE_DIG + 0x133)
#define HI6403_HPR_SDM_NEW_CTRL1_REG       (BASE_ADDR_PAGE_DIG + 0x134)
#define HI6403_HPR_SDM_NEW_CTRL2_REG       (BASE_ADDR_PAGE_DIG + 0x135)
#define HI6403_HPR_SDM_NEW_CTRL3_REG       (BASE_ADDR_PAGE_DIG + 0x136)
#define HI6403_HPR_SDM_NEW_CTRL4_REG       (BASE_ADDR_PAGE_DIG + 0x137)
#define HI6403_HPR_SDM_NEW_CTRL5_REG       (BASE_ADDR_PAGE_DIG + 0x138)

/* MUX FOR DAC SDM45 */
#define HI6403_DACL_SDM45_MUX_SEL          (BASE_ADDR_PAGE_DIG + 0x13C)
#define HI6403_DACR_SDM45_MUX_SEL          (BASE_ADDR_PAGE_DIG + 0x140)
#define HI6403_DAC_SDM45_MUX_BIT           0

/* SDM CONFIG */
#define HI6403_HPL_SDM45_CONFIG_REG0       (BASE_ADDR_PAGE_DIG + 0x139)
#define HI6403_HP_SDM_L_CELL_SEL_EN_BIT    6
#define HI6403_HP_SDM_L_DEM_DSEN_BIT       5
#define HI6403_HP_SDM_L_BIT                0

#define HI6403_HP_SDM45_CONFIG_SHADOW_REG0        (BASE_ADDR_PAGE_DIG + 0x159)
#define HI6403_HP_SDM_R_CELL_SEL_EN_SHADOW_BIT    2
#define HI6403_HP_SDM_L_CELL_SEL_EN_SHADOW_BIT    0

#define HI6403_HPL_SDM45_CONFIG_REG1       (BASE_ADDR_PAGE_DIG + 0x13A)
#define HI6403_HPL_SDM45_CONFIG_REG2       (BASE_ADDR_PAGE_DIG + 0x13B)
#define HI6403_HPL_SDM45_CONFIG_REG3       (BASE_ADDR_PAGE_DIG + 0x13C)

#define HI6403_HPR_SDM45_CONFIG_REG0       (BASE_ADDR_PAGE_DIG + 0x13D)
#define HI6403_HP_SDM_R_CELL_SEL_EN_BIT    6
#define HI6403_HP_SDM_R_DEM_DSEN_BIT       5
#define HI6403_HP_SDM_R_BIT                0

#define HI6403_HPR_SDM45_CONFIG_REG1       (BASE_ADDR_PAGE_DIG + 0x13E)
#define HI6403_HPR_SDM45_CONFIG_REG2       (BASE_ADDR_PAGE_DIG + 0x13F)
#define HI6403_HPR_SDM45_CONFIG_REG3       (BASE_ADDR_PAGE_DIG + 0x140)

#define HI6403_HP_SW_CTRL0_REG             (BASE_ADDR_PAGE_DIG + 0x151)
#define HI6403_HP_SW_CTRL1_REG             (BASE_ADDR_PAGE_DIG + 0x152)
#define HI6403_HP_SW_CTRL2_REG             (BASE_ADDR_PAGE_DIG + 0x153)
#define HI6403_HP_SW_CTRL3_REG             (BASE_ADDR_PAGE_DIG + 0x154)
#define HI6403_HP_SW_CTRL4_REG             (BASE_ADDR_PAGE_DIG + 0x155)
#define HI6403_HP_SW_CTRL5_REG             (BASE_ADDR_PAGE_DIG + 0x156)

#define HI6403_HP_SW_CTRL10_REG            (BASE_ADDR_PAGE_DIG + 0x160)
#define HI6403_HP_SW_TYPEB_CTRL_BIT        2
#define HI6403_HP_SW_TRIGGER_BIT           1
#define HI6403_HP_SW_EN_BIT                0

#define HI6403_PGA_ZC_CFG_REG_0            (BASE_ADDR_PAGE_DIG + 0x200)
#define HI6403_PGA_ZC_CFG_REG_1            (BASE_ADDR_PAGE_DIG + 0x201)
#define HI6403_PGA_ZC_CFG_REG_2            (BASE_ADDR_PAGE_DIG + 0x202)
#define HI6403_PGA_ZC_CFG_REG_3            (BASE_ADDR_PAGE_DIG + 0x203)
#define HI6403_PGA_ZC_CFG_REG_4            (BASE_ADDR_PAGE_DIG + 0x204)
#define HI6403_PGA_ZC_CFG_REG_5            (BASE_ADDR_PAGE_DIG + 0x205)
#define HI6403_PGA_ZC_CFG_REG_6            (BASE_ADDR_PAGE_DIG + 0x206)
#define HI6403_PGA_ZC_CFG_REG_7            (BASE_ADDR_PAGE_DIG + 0x207)
#define HI6403_PGA_ZC_CFG_REG_8            (BASE_ADDR_PAGE_DIG + 0x208)
#define HI6403_PGA_ZC_CFG_BIT              0

/* U3U4 SRC MODE CONFIG */
#define HI6403_U3_SRC_MODE_CFG_REG         (BASE_ADDR_PAGE_DIG + 0x237)
#define HI6403_U4_SRC_MODE_CFG_REG         (BASE_ADDR_PAGE_DIG + 0x238)

/* MIC12 MUX SELETCT*/
#define HI6403_MIC12_MUX_SEL               (BASE_ADDR_PAGE_DIG + 0x008)
#define HI6403_MIC2_MUX_BIT                4
#define HI6403_MIC1_MUX_BIT                0

/* MIC12 MUX SELETCT*/
#define HI6403_MIC34_MUX_SEL               (BASE_ADDR_PAGE_DIG + 0x009)
#define HI6403_MIC4_MUX_BIT                4
#define HI6403_MIC3_MUX_BIT                0

/* BT MUX SELECT */
#define HI6403_BT_MUX_SEL                  (BASE_ADDR_PAGE_DIG + 0x00A)
#define HI6403_BTR_MUX_BIT                 4
#define HI6403_BTL_MUX_BIT                 0

/* M1 MUX SELECT */
#define HI6403_M1_MUX_SEL                  (BASE_ADDR_PAGE_DIG + 0x00B)
#define HI6403_M1R_MUX_BIT                 4
#define HI6403_M1L_MUX_BIT                 0

/* DSP IF BYPASS CONFIG */
#define HI6403_S1_DSPIF_CONTROL_REG        (BASE_ADDR_PAGE_DIG + 0x02D)
#define HI6403_S1_DSPIF_OUT_BIT            7
#define HI6403_S1_DSPIF_IN_BIT             6

#define HI6403_S2_DSPIF_CONTROL_REG        (BASE_ADDR_PAGE_DIG + 0x03C)
#define HI6403_S2_DSPIF_OUT_BIT            7
#define HI6403_S2_DSPIF_IN_BIT             6
#define HI6403_S2OR_SRC_MODE_BIT           3
#define HI6403_S2OL_SRC_MODE_BIT           0

#define HI6403_S4_DSPIF_CONTROL_REG        (BASE_ADDR_PAGE_DIG + 0x04D)
#define HI6403_S4_DSPIF_OUT_BIT            7
#define HI6403_S4_DSPIF_IN_BIT             6


/* ANC MUX SELECT */
#define HI6403_ANC_MUX_SEL                 (BASE_ADDR_PAGE_DIG + 0x284)
#define HI6403_NEARMIC_MUX_BIT             6
#define HI6403_ANC_FAREND_MUX_BIT          4
#define HI6403_ANC_DATA_MUX_BIT            4
#define HI6403_ERROR_MIC_MUX_BIT           2
#define HI6403_REF_MIC_MUX_BIT             0
#define HI6403_NOISE_MIC_MUX_BIT           0

/* PDM MUX SELECT */
#define HI6403_ADC_SOURCE_SEL              (BASE_ADDR_PAGE_DIG + 0x091)

#define HI6403_MAD_CFG_REG                 (BASE_ADDR_PAGE_DIG + 0x121)
#define HI6403_MAD_VAD_ON_BIT              6
#define HI6403_MAD_INT_EN_BIT              5
#define HI6403_MAD_EN_BIT                  0

/* DACR SDM MUX SELECT */
#define HI6403_DACR_SDM_MUX_SEL            (BASE_ADDR_PAGE_DIG + 0x142)
#define HI6403_DACR_SDM_MUX_BIT            6

/* DACSR SDM MUX SELECT */
#define HI6403_DACSR_SDM_MUX_SEL           (BASE_ADDR_PAGE_DIG + 0x144)
#define HI6403_DACSR_SDM_MUX_BIT           6

/* DACL SDM MUX SELECT */
#define HI6403_DACL_SDM_MUX_SEL            (BASE_ADDR_PAGE_DIG + 0x141)
#define HI6403_DACL_SDM_MUX_BIT            6

/* DACSL SDM MUX SELECT */
#define HI6403_DACSL_SDM_MUX_SEL           (BASE_ADDR_PAGE_DIG + 0x143)
#define HI6403_DACSL_SDM_MUX_BIT           6

/* DAC HP MUX SELECT */
#define HI6403_DAC_HP_MUX_SEL              (BASE_ADDR_PAGE_DIG + 0x149)
#define HI6403_DAC_HPR_MUX_BIT             3
#define HI6403_DAC_HPL_MUX_BIT             0

/* DACS MUX SELECT */
#define HI6403_DACS_MUX_SEL                (BASE_ADDR_PAGE_DIG + 0x14A)
#define HI6403_DAC_LTL_MUX_BIT             3
#define HI6403_DAC_EP_MUX_BIT              0

/* DAC LINEOUT R MUX SELECT */
#define HI6403_DAC_LTR_MUX_SEL             (BASE_ADDR_PAGE_DIG + 0x14B)
#define HI6403_DAC_LTR_MUX_BIT             0

#define HI6403_SLIM_UP_EN2                 (BASE_ADDR_PAGE_DIG + 0x1FF)
#define HI6403_SLIMBUS_UP12_DATA_SEL       0
#define HI6403_SLIMBUS_UP56_DATA_SEL       1

/* IMP DETECT CONTROL */
#define HI6403_IMP_DET_CTRL_REG            (BASE_ADDR_PAGE_DIG + 0x23C)
#define HI6403_IMP_EN_BIT                  7
#define HI6403_IMP_SAMP_CFG                0

/* DSP IF 8 TEST MUX SELECT */
#define HI6403_IF8_TEST_MUX_SEL            (BASE_ADDR_PAGE_DIG + 0x011)
#define HI6403_IF8_TEST_MUX_BIT            0

/* DACSL MIXER SELECT */
#define HI6403_DACSL_MIXER_SEL_0           (BASE_ADDR_PAGE_DIG + 0x056)
#define HI6403_DACSL_MIXER_MDM_BIT         7
#define HI6403_DACSL_MIXER_OL_BIT          6
#define HI6403_DACSL_MIXER_DACL_BIT        5
#define HI6403_DACSL_MIXER_SEL_1           (BASE_ADDR_PAGE_DIG + 0x057)
#define HI6403_DACSL_MIXER_FS_BIT          7
#define HI6403_DACSL_MIXER_SIDETONE_BIT    5

/* DACSR MIXER SELECT */
#define HI6403_DACSR_MIXER_SEL_0           (BASE_ADDR_PAGE_DIG + 0x059)
#define HI6403_DACSR_MIXER_MDM_BIT         7
#define HI6403_DACSR_MIXER_OR_BIT          6
#define HI6403_DACSR_MIXER_DACR_BIT        5
#define HI6403_DACSR_MIXER_SEL_1           (BASE_ADDR_PAGE_DIG + 0x05A)
#define HI6403_DACSR_MIXER_FS_BIT          7
#define HI6403_DACSR_MIXER_SIDETONE_BIT    5

/* SC_DAC_DC_1 */
#define HI6403_SC_DAC_DC_1                 (BASE_ADDR_PAGE_DIG + 0x078)

/* DACL FLT MIXER SELECT */
#define HI6403_DACL_FLT_MIXER_SEL          (BASE_ADDR_PAGE_DIG + 0x218)
#define HI6403_DACL_FLT_MIXER_FS_CFG_BIT   7
#define HI6403_DACL_FLT_MIXER_1_BIT        6
#define HI6403_DACL_FLT_MIXER_0_BIT        5

/* DACR FLT MIXER SELECT */
#define HI6403_DACR_FLT_MIXER_SEL          (BASE_ADDR_PAGE_DIG + 0x21B)
#define HI6403_DACR_FLT_MIXER_FS_CFG_BIT   7
#define HI6403_DACR_FLT_MIXER_1_BIT        6
#define HI6403_DACR_FLT_MIXER_0_BIT        5

#define HI6403_PGA_BYPASS_REG0           (BASE_ADDR_PAGE_DIG + 0x249)
#define HI6403_PGA_BYPASS_REG1           (BASE_ADDR_PAGE_DIG + 0x24A)
#define HI6403_PGA_BYPASS_REG2           (BASE_ADDR_PAGE_DIG + 0x24B)

/* LUT1B for EARPHONE */
#define HI6403_LUT1B_CFG_REG0              (BASE_ADDR_PAGE_DIG + 0x364)
#define HI6403_LUT1B_CFG_REG1              (BASE_ADDR_PAGE_DIG + 0x365)
#define HI6403_LUT1B_CFG_REG2              (BASE_ADDR_PAGE_DIG + 0x366)
#define HI6403_LUT1B_CFG_REG3              (BASE_ADDR_PAGE_DIG + 0x367)
#define HI6403_LUT1B_CFG_REG4              (BASE_ADDR_PAGE_DIG + 0x368)
#define HI6403_LUT1B_CFG_REG5              (BASE_ADDR_PAGE_DIG + 0x369)
#define HI6403_LUT1B_CFG_REG6              (BASE_ADDR_PAGE_DIG + 0x36A)
#define HI6403_LUT1B_CFG_REG7              (BASE_ADDR_PAGE_DIG + 0x36B)
#define HI6403_LUT1B_CFG_REG8              (BASE_ADDR_PAGE_DIG + 0x36C)
#define HI6403_LUT1B_CFG_REG9              (BASE_ADDR_PAGE_DIG + 0x36D)
#define HI6403_LUT1B_CFG_REG10             (BASE_ADDR_PAGE_DIG + 0x36E)
#define HI6403_LUT1B_CFG_REG11             (BASE_ADDR_PAGE_DIG + 0x36F)
#define HI6403_LUT1B_CFG_REG12             (BASE_ADDR_PAGE_DIG + 0x370)
#define HI6403_LUT1B_CFG_REG13             (BASE_ADDR_PAGE_DIG + 0x371)
#define HI6403_LUT1B_CFG_REG14             (BASE_ADDR_PAGE_DIG + 0x372)
#define HI6403_LUT1B_CFG_REG15             (BASE_ADDR_PAGE_DIG + 0x373)
#define HI6403_LUT1B_CFG_REG16             (BASE_ADDR_PAGE_DIG + 0x374)
#define HI6403_LUT1B_CFG_REG17             (BASE_ADDR_PAGE_DIG + 0x375)
#define HI6403_LUT1B_CFG_REG18             (BASE_ADDR_PAGE_DIG + 0x376)
#define HI6403_LUT1B_CFG_REG19             (BASE_ADDR_PAGE_DIG + 0x377)
#define HI6403_LUT1B_CFG_REG20             (BASE_ADDR_PAGE_DIG + 0x378)
#define HI6403_LUT1B_CFG_REG21             (BASE_ADDR_PAGE_DIG + 0x379)
#define HI6403_LUT1B_CFG_REG22             (BASE_ADDR_PAGE_DIG + 0x37A)
#define HI6403_LUT1B_CFG_REG23             (BASE_ADDR_PAGE_DIG + 0x37B)
#define HI6403_LUT1B_CFG_REG24             (BASE_ADDR_PAGE_DIG + 0x37C)
#define HI6403_LUT1B_CFG_REG25             (BASE_ADDR_PAGE_DIG + 0x37D)
#define HI6403_LUT1B_CFG_REG26             (BASE_ADDR_PAGE_DIG + 0x37E)
#define HI6403_LUT1B_CFG_REG27             (BASE_ADDR_PAGE_DIG + 0x37F)
#define HI6403_LUT1B_CFG_REG28             (BASE_ADDR_PAGE_DIG + 0x380)
#define HI6403_LUT1B_CFG_REG29             (BASE_ADDR_PAGE_DIG + 0x381)
#define HI6403_LUT1B_CFG_REG30             (BASE_ADDR_PAGE_DIG + 0x382)

/* zero cross config for classH */
#define HI6403_PERF_SWITCH_CTRL0           (BASE_ADDR_PAGE_DIG + 0x151)
#define HI6403_PERF_SWITCH_CTRL1           (BASE_ADDR_PAGE_DIG + 0x152)
#define HI6403_PERF_SWITCH_CTRL2           (BASE_ADDR_PAGE_DIG + 0x153)
#define HI6403_PERF_SWITCH_CTRL3           (BASE_ADDR_PAGE_DIG + 0x154)
#define HI6403_PERF_SWITCH_CTRL4           (BASE_ADDR_PAGE_DIG + 0x155)
#define HI6403_PERF_SWITCH_CTRL5           (BASE_ADDR_PAGE_DIG + 0x156)

/* the shadow config for classH */
#define HI6403_PERF_SWITCH_CTRL6           (BASE_ADDR_PAGE_DIG + 0x157)
#define HI6403_PERF_SWITCH_CTRL7           (BASE_ADDR_PAGE_DIG + 0x158)

#define HI6403_ANALOG_REG38_SHADOW         (BASE_ADDR_PAGE_CFG + 0x1F9)
#define HI6403_DAC_HP_VBR_SEL_SHADOW_BIT   4
#define HI6403_HP_RES_CT_SHADOW_BIT        0

#define HI6403_ANALOG_REG39_SHADOW         (BASE_ADDR_PAGE_CFG + 0x1FA)
#define HI6403_DAC_HP_PLAN_SEL_SHADOW_BIT      2
#define HI6403_DAC_HP_PLAN_SEL_BIT_SHADOW      2
#define HI6403_DAC_HP_PLANA_HVR_SEL_SHADOW_BIT       1
#define HI6403_DAC_HP_VBR_SEL_BIT_SHADOW       1
#define HI6403_DAC_HP_VBSWEN_SHADOW_BIT        0
#define HI6403_DAC_HP_VBSWEN_BIT_SHADOW        0

#define HI6403_ANALOG_REG40_SHADOW         (BASE_ADDR_PAGE_CFG + 0x1FB)
#define HI6403_DAC_HPL_HI_CELLOFF_EN_SHADOW    1
#define HI6403_DAC_HPR_HI_CELLOFF_EN_SHADOW    0

#define HI6403_ANALOG_REG41_SHADOW         (BASE_ADDR_PAGE_CFG + 0x1FC)

#define HI6403_ANALOG_REG48_SHADOW         (BASE_ADDR_PAGE_CFG + 0x1FD)
#define HI6403_HP_GND_CTR_BIT_SHADOW           7
#define HI6403_HP_GND_CTR_SHADOW_BIT           7
#define HI6403_HP_SRB_CTRL_SHADOW_BIT          6
#define HI6403_HP_FB_EN_BIT_SHADOW             6
#define HI6403_HP_IBCT_SHADOW_BIT              4
#define HI6403_HP_IBCT_BIT_SHADOW              4
#define HI6403_HP_FB_EN_SHADOW_BIT             3
#define HI6403_HP_SRB_CTRL_BIT_SHADOW          3
#define HI6403_HP_FB_STB_CTRL_SHADOW_BIT       2
#define HI6403_HP_FB_IBCT_SHADOW_BIT           0
#define HI6403_HP_RES_CT_BIT_SHADOW            0

#define HI6403_ANALOG_REG49_SHADOW             (BASE_ADDR_PAGE_CFG + 0x1FE)
#define HI6403_HP_FB_RES_CT_SHADOW_BIT         0
#define HI6403_HP_FB_IBCT_BIT_SHADOW           4

#define HI6403_ANALOG_REG73_SHADOW             (BASE_ADDR_PAGE_CFG + 0x1FF)
#define HI6403_IB05_HP_FB_SHADOW_BIT           0
#define HI6403_HP_FB_RES_CT_BIT_SHADOW         0
#define HI6403_HP_FB_STB_CTRL_BIT_SHADOW       3
#define HI6403_IB05_HP_SHADOW_BIT              4

#define HI6403_MADMIC_SEL_BIT                  0
#define HI6403_IB05_HP_FB_SHADOW_BIT           0

/* main gain switch config for classH */
#define HI6403_PERF_SWITCH_CTRL8         (BASE_ADDR_PAGE_DIG + 0x159)
#define HI6403_PERF_TRIGGER_EN_BIT        1
#define HI6403_PERF_SWITCH_EN_BIT         0

#define HI6403_PER_SWITCH_STAT           (BASE_ADDR_PAGE_DIG + 0x3AA)

/* S1 PORT FS CONFIG */
#define HI6403_S1_CLK_CFG_REG0          (BASE_ADDR_PAGE_DIG + 0x0AE)
#define HI6403_S1_SRCOR_CLK_BIT         7
#define HI6403_S1_SRCOL_CLK_BIT         6
#define HI6403_S1_SRCIR_CLK_BIT         5
#define HI6403_S1_SRCIL_CLK_BIT         4

#define HI6403_S1_CLK_CFG_REG1          (BASE_ADDR_PAGE_DIG + 0x0AF)

/* SLIMBUS UP EN */
#define HI6403_SLIM_UP_CLKEN_REG        (BASE_ADDR_PAGE_DIG + 0x1FE)
#define HI6403_SLIM_UP_CLKEN_8_BIT      7
#define HI6403_SLIM_UP_CLKEN_7_BIT      6
#define HI6403_SLIM_UP_CLKEN_6_BIT      5
#define HI6403_SLIM_UP_CLKEN_5_BIT      4
#define HI6403_SLIM_UP_CLKEN_4_BIT      3
#define HI6403_SLIM_UP_CLKEN_3_BIT      2
#define HI6403_SLIM_UP_CLKEN_2_BIT      1
#define HI6403_SLIM_UP_CLKEN_1_BIT      0


#define HI6403_S2_CFG_REG               (BASE_ADDR_PAGE_DIG + 0x002)
#define HI6403_S2_MODE_CFG_BIT          5
#define HI6403_S2_DRIECT_CFG_BIT        3
#define HI6403_S2_MST_SLV_SEL_BIT       2
#define HI6403_S2_RX_EN_BIT             1
#define HI6403_S2_TX_EN_BIT             0

#define HI6403_S2_CFG_REG_H             (BASE_ADDR_PAGE_DIG + 0x003)
#define HI6403_S2_RX_CLK_SEL_BIT        7
#define HI6403_S2_TX_CLK_SEL_BIT        6
#define HI6403_S2_WORD_LENG_BIT         4
#define HI6403_S2_FORMA_BIT             3
#define HI6403_S2_CHNNL_MODE_BIT        2
#define HI6403_S2_LRCLK_MODE_BIT        1
#define HI6403_S2_FRAME_MODE_BIT        0

#define HI6403_S3_CFG_REG_H             (BASE_ADDR_PAGE_DIG + 0x004)
#define HI6403_S3_IF_RX_EN_BIT          1
#define HI6403_S3_IF_TX_EN_BIT          0

#define HI6403_S4_CFG_REG               (BASE_ADDR_PAGE_DIG + 0x006)
#define HI6403_S4_MODE_CFG_BIT          5
#define HI6403_S4_DRIECT_CFG_BIT        3
#define HI6403_S4_MST_SLV_SEL_BIT       2
#define HI6403_S4_RX_EN_BIT             1
#define HI6403_S4_TX_EN_BIT             0

#define HI6403_S4_CFG_REG_H             (BASE_ADDR_PAGE_DIG + 0x007)
#define HI6403_S4_RX_CLK_SEL_BIT        7
#define HI6403_S4_TX_CLK_SEL_BIT        6
#define HI6403_S4_WORD_LENG_BIT         4
#define HI6403_S4_FORMA_BIT             3
#define HI6403_S4_CHNNL_MODE_BIT        2
#define HI6403_S4_IRCLK_MODE_BIT        1
#define HI6403_S4_FRAME_MODE_BIT        0

/*SC CODEC MUX SEL1_3*/
#define HI6403_SC_CODEC_MUX_SEL1_3_REG  (BASE_ADDR_PAGE_DIG + 0x00F)

#define HI6403_DSPIF8_MUX_REG           (BASE_ADDR_PAGE_DIG + 0x011)
#define HI6403_DSPIF8_MUX_BIT           0

/*ADC */
#define HI6403_ADC1L_R_REG              (BASE_ADDR_PAGE_DIG + 0x093)
#define HI6403_SC_FS_ADC_REG            (BASE_ADDR_PAGE_DIG + 0x0F1)

/* S1 PGA CFG */
#define HI6403_S1_PGA_IL_GAIN_CFG_REG      (BASE_ADDR_PAGE_DIG + 0x021)
#define HI6403_S1_PGA_IL_GAIN_BIT          0
#define HI6403_S1_PGA_IR_GAIN_CFG_REG      (BASE_ADDR_PAGE_DIG + 0x024)
#define HI6403_S1_PGA_IR_GAIN_BIT          0

/* S2 PGA CFG */
#define HI6403_S2_PGA_IL_GAIN_CFG_REG      (BASE_ADDR_PAGE_DIG + 0x02F)
#define HI6403_S2_PGA_IL_GAIN_BIT          0
#define HI6403_S2_PGA_IR_GAIN_CFG_REG      (BASE_ADDR_PAGE_DIG + 0x032)
#define HI6403_S2_PGA_IR_GAIN_BIT          0

/* S3 PGA CFG */
#define HI6403_S3_PGA_IL_GAIN_CFG_REG      (BASE_ADDR_PAGE_DIG + 0x03E)
#define HI6403_S3_PGA_IL_GAIN_BIT          0
#define HI6403_S3_PGA_IR_GAIN_CFG_REG      (BASE_ADDR_PAGE_DIG + 0x041)
#define HI6403_S3_PGA_IR_GAIN_BIT          0
#define HI6403_S3_PGA_IL_CFG_REG           (BASE_ADDR_PAGE_DIG + 0x03F)
#define HI6403_S3_PGA_IL_FD_EN_BIT         7

/* DACL MIXER GAIN CFG */
#define HI6403_DACL_MIXER_GAIN_CFG_REG     (BASE_ADDR_PAGE_DIG + 0x04F)
#define HI6403_DACL_MIXER_S1R_GAIN_BIT     6
#define HI6403_DACL_MIXER_MDM_GAIN_BIT     4
#define HI6403_DACL_MIXER_S2L_GAIN_BIT     2
#define HI6403_DACL_MIXER_S1L_GAIN_BIT     0

/* DACR MIXER GAIN CFG */
#define HI6403_DACR_MIXER_GAIN_CFG_REG     (BASE_ADDR_PAGE_DIG + 0x052)
#define HI6403_DACR_MIXER_S1L_GAIN_BIT     6
#define HI6403_DACR_MIXER_MDM_GAIN_BIT     4
#define HI6403_DACR_MIXER_S2R_GAIN_BIT     2
#define HI6403_DACR_MIXER_S1R_GAIN_BIT     0

/* DACSL MIXER GAIN CFG */
#define HI6403_DACSL_MIXER_GAIN_CFG_REG    (BASE_ADDR_PAGE_DIG + 0x055)
#define HI6403_DACSL_MIXER_MDM_GAIN_BIT    6
#define HI6403_DACSL_MIXER_OL_GAIN_BIT     4
#define HI6403_DACSL_MIXER_SIDE_GAIN_BIT   2
#define HI6403_DACSL_MIXER_1L_GAIN_BIT     0

/* DACSR MIXER GAIN CFG */
#define HI6403_DACSR_MIXER_GAIN_CFG_REG    (BASE_ADDR_PAGE_DIG + 0x058)
#define HI6403_DACSR_MIXER_MDM_GAIN_BIT    6
#define HI6403_DACSR_MIXER_OR_GAIN_BIT     4
#define HI6403_DACSR_MIXER_SIDE_GAIN_BIT   2
#define HI6403_DACSR_MIXER_1R_GAIN_BIT     0

/* SIDE PGA CFG */
#define HI6403_SIDE_PGA_GAIN_CFG_REG       (BASE_ADDR_PAGE_DIG + 0x05D)
#define HI6403_SIDE_PGA_GAIN_BIT           0

/* DAC PGA CFG */
#define HI6403_DACL_PGA_GAIN_CFG_REG       (BASE_ADDR_PAGE_DIG + 0x080)
#define HI6403_DACL_PGA_GAIN_BIT           0

#define HI6403_DACL_PGA_GAIN_VIRTUAL_REG  (BASE_ADDR_PAGE_MM + 0x1)

#define HI6403_DACL_PGA_CFG_REG            (BASE_ADDR_PAGE_DIG + 0x081)
#define HI6403_DACL_PGA_FD_EN_BIT          7

#define HI6403_DACR_PGA_GAIN_CFG_REG       (BASE_ADDR_PAGE_DIG + 0x083)
#define HI6403_DACR_PGA_GAIN_BIT           0

#define HI6403_DACR_PGA_GAIN_VIRTUAL_REG  (BASE_ADDR_PAGE_MM + 0x2)

#define HI6403_ADC0L_05PGA_GAIN_VIRTUAL_REG  (BASE_ADDR_PAGE_MM + 0x3)
#define HI6403_ADC0L_05PGA_GAIN_VIRTUAL_BIT  0

#define HI6403_ADC0R_05PGA_GAIN_VIRTUAL_REG  (BASE_ADDR_PAGE_MM + 0x4)
#define HI6403_ADC0R_05PGA_GAIN_VIRTUAL_BIT  0

#define HI6403_ADC1L_05PGA_GAIN_VIRTUAL_REG  (BASE_ADDR_PAGE_MM + 0x5)
#define HI6403_ADC1L_05PGA_GAIN_VIRTUAL_BIT  0

#define HI6403_ADC1R_05PGA_GAIN_VIRTUAL_REG  (BASE_ADDR_PAGE_MM + 0x6)
#define HI6403_ADC1R_05PGA_GAIN_VIRTUAL_BIT  0

#define HI6403_DACR_PGA_CFG_REG            (BASE_ADDR_PAGE_DIG + 0x084)
#define HI6403_DACR_PGA_FD_EN_BIT          7

/* MUX OF DAC PGA IN */
#define HI6403_DACL_PGA_MUX_SEL            (BASE_ADDR_PAGE_DIG + 0x089)
#define HI6403_DACR_PGA_MUX_SEL            (BASE_ADDR_PAGE_DIG + 0x08A)
#define HI6403_DAC_PGA_MUX_BIT             6

/* MUX FOR ADC0 */
#define HI6403_ADC0_MUX_SEL                (BASE_ADDR_PAGE_DIG + 0x094)
#define HI6403_ADCR0_MUX_BIT               4
#define HI6403_ADCL0_MUX_BIT               0

/* MUX FOR ADC1 */
#define HI6403_ADC1_MUX_SEL                (BASE_ADDR_PAGE_DIG + 0x095)
#define HI6403_ADCR1_MUX_BIT               4
#define HI6403_ADCL1_MUX_BIT               0

/* MDM MUX SELECT */
#define HI6403_MDM_MUX_SEL                 (BASE_ADDR_PAGE_DIG + 0x012)
#define HI6403_MDM_MUX_BIT                 0

/* SIDETONE MUX SELECT */
#define HI6403_SIDETONE_MUX_SEL            (BASE_ADDR_PAGE_DIG + 0x012)
#define HI6403_SIDETONE_MUX_BIT            4

/* I2S/SLIM SEL */
#define HI6403_I2S_SLIM_SEL_REG            (BASE_ADDR_PAGE_DIG + 0x014)

#define HI6403_S2_CONTROL_REG              (BASE_ADDR_PAGE_DIG + 0x03B)
#define HI6403_S2IR_SRC_MODE_BIT           5
#define HI6403_S2IL_SRC_MODE_BIT           1

#define HI6403_S3_CONTROL_REG              (BASE_ADDR_PAGE_DIG + 0x04A)
#define HI6403_S3IR_SRC_MODE_BIT           5
#define HI6403_S3IL_SRC_MODE_BIT           1
#define HI6403_S3_DSPIF_CONTROL_REG        (BASE_ADDR_PAGE_DIG + 0x04B)
#define HI6403_S3_DSPIF_OUT_BIT            7
#define HI6403_S3_DSPIF_IN_BIT             6
#define HI6403_S3OR_SRC_MODE_BIT           3
#define HI6403_S3OL_SRC_MODE_BIT           0

/* PDM MUX SELECT */
#define HI6403_PDM_MUX_SEL                 (BASE_ADDR_PAGE_DIG + 0x097)
#define HI6403_PDM_MUX_BIT                 1

/* MIXER REG */
/* DACL MIXER SELECT */
#define HI6403_DACL_MIXER_SEL_0            (BASE_ADDR_PAGE_DIG + 0x050)
#define HI6403_DACL_MIXER_MDM_BIT          7
#define HI6403_DACL_MIXER_S2L_BIT          6
#define HI6403_DACL_MIXER_S1L_BIT          5
#define HI6403_DACL_MIXER_SEL_1            (BASE_ADDR_PAGE_DIG + 0x051)
#define HI6403_DACL_MIXER_S1R_BIT          5

/* DACR MIXER SELECT */
#define HI6403_DACR_MIXER_SEL_0            (BASE_ADDR_PAGE_DIG + 0x053)
#define HI6403_DACR_MIXER_MDM_BIT          7
#define HI6403_DACR_MIXER_S2R_BIT          6
#define HI6403_DACR_MIXER_S1R_BIT          5

#define HI6403_DACR_MIXER_SEL_1            (BASE_ADDR_PAGE_DIG + 0x054)
#define HI6403_DACR_MIXER_S1L_BIT          5

/* DACSL SRC MIXER SELECT */
#define HI6403_DACSL_SRC_MIXER_SEL         (BASE_ADDR_PAGE_DIG + 0x0B8)
#define HI6403_DACSL_MIXER_1_BIT           6
#define HI6403_DACSL_MIXER_0_BIT           5

/* DACSR SRC MIXER SELECT */
#define HI6403_DACSR_SRC_MIXER_SEL         (BASE_ADDR_PAGE_DIG + 0x0BB)
#define HI6403_DACSR_MIXER_1_BIT           6
#define HI6403_DACSR_MIXER_0_BIT           5

/* MIXER CLK ENABLE */
#define HI6403_DAC_MIXER_CLK_REG           (BASE_ADDR_PAGE_CFG + 0x047)
#define HI6403_DACSR_MIXER_EN_BIT          3
#define HI6403_DACSL_MIXER_EN_BIT          2
#define HI6403_DACR_MIXER_EN_BIT           1
#define HI6403_DACL_MIXER_EN_BIT           0

#define HI6403_DAC_SRC_MIXER_CLK_REG       (BASE_ADDR_PAGE_CFG + 0x04C)
#define HI6403_DACR_FLT_MIXER_EN_BIT       3
#define HI6403_DACL_FLT_MIXER_EN_BIT       2
#define HI6403_DACR_SRC_MIXER_EN_BIT       1
#define HI6403_DACL_SRC_MIXER_EN_BIT       0

/* DSP CFG */
#define HI6403_SW_RST_REQ                 (BASE_ADDR_PAGE_CFG + 0x001)
#define HI6403_AUD_12M_SRST_REQ_BIT        0
#define HI6403_AUD_11M_SRST_REQ_BIT        1
#define HI6403_HIFI_SRST_REQ_BIT           2
#define HI6403_HIFI_CORE_SRST_REQ_BIT      3
#define HI6403_PERI_SRST_REQ_BIT           4
#define HI6403_DSP_PD_SRST_REQ_BIT         5
#define HI6403_HIFI_PERI_SRST_REQ_BIT      6
#define HI6403_DSD_SRST_REQ_BIT            7

#define HI6403_SC_DSP_CTRL0                (BASE_ADDR_PAGE_CFG + 0x004)
#define HI6403_SC_DSP_EN_BIT               0
#define HI6403_SC_DSP_BP_BIT               1
#define HI6403_SC_DSP_SFT_RUNSTALL_BIT     2
#define HI6403_SC_HIFI_CLK_EN_BIT          3
#define HI6403_SC_HIFI_ACLK_EN_BIT         4
#define HI6403_SC_DSP_RUNSTALL_BP_BIT      6
#define HI6403_SC_DSP_HIFI_DIV_BP_BIT      7

#define HI6403_SC_MAD_CTRL0                (BASE_ADDR_PAGE_CFG + 0x013)
#define HI6403_SC_MAD_CG_EN_BIT            0
#define HI6403_SC_MAD_ANA_BP_BIT           1
#define HI6403_SC_MAD_PLL_BP_BIT           2
#define HI6403_SC_MAD_MIC_BP_BIT           3
#define HI6403_SC_MAD_PGA_BP_BIT           4
#define HI6403_SC_MAD_AUD_CLK_EN_BP_BIT    5
#define HI6403_MAD_CFG_REG_CG_EN_BIT       6

#define HI6403_CFG_REG_CLK_CTRL            (BASE_ADDR_PAGE_CFG + 0x038)
#define HI6403_REGFILE_CLK_CG_EN_BIT       4

#define HI6403_UART_DIV_EN                 (BASE_ADDR_PAGE_CFG + 0x03B)
#define HI6403_UART_DIV_EN_BIT             7

#define HI6403_DSP_LP_CTRL0                (BASE_ADDR_PAGE_CFG + 0x050)
#define HI6403_DSP_TOP_MTCMOS_CTRL_BIT     0
#define HI6403_DSP_TOP_ISO_CTRL_BIT        1
#define HI6403_AXI_CSYSREQ_BIT             6

#define HI6403_DSP_LP_STATUS0              (BASE_ADDR_PAGE_CFG + 0x051)
#define HI6403_DSP_MTCMOS_RDY_BIT          0

#define HI6403_DSP_CLK_CFG                 (BASE_ADDR_PAGE_CFG + 0x052)
#define HI6403_HIFI_DIV_NUM_BIT            0
#define HI6403_HIFI_ADIV_NUM_BIT           4
#define HI6403_HIFI_DIV_CLK_EN_BIT         6

#define HI6403_APB_CLK_CFG                 (BASE_ADDR_PAGE_CFG + 0x053)
#define HI6403_APB_CLK_EN_BIT              0
#define HI6403_TIMER0_PCLK_EN_BIT          1
#define HI6403_TIMER1_PCLK_EN_BIT          2
#define HI6403_WD_PCLK_EN_BIT              3
#define HI6403_GPIO_PCLK_EN_BIT            4
#define HI6403_APB2RAM_PCLK_EN_BIT         5
#define HI6403_APB_PD_PCLK_EN_BIT          6
#define HI6403_PERI_CLK_SEL_BIT            7

#define HI6403_DSP_CTRL6_DMAC              (BASE_ADDR_PAGE_CFG + 0x054)
#define HI6403_DW_AXI_X2P_CG_EN            0
#define HI6403_DW_AXI_X2P_ASYNC_CG_EN      1
#define HI6403_DMAC_ACLK0_CG_EN            2
#define HI6403_DMAC_ACLK1_CG_EN            3
#define HI6403_DW_X2X_CG_EN                4
#define HI6403_UART_CG_EN                  5
#define HI6403_HIFI_PREI_CLK_EN            6
#define HI6403_PERI_DW_AXI_X2P_CG_EN       7

/* DSP_PERI_CLKEN1 */
#define HI6403_DSP_PERI_CLKEN1             (BASE_ADDR_PAGE_CFG + 0x056)
#define HI6403_WATCHDOG_DIV_BITS           0
#define HI6403_I2C_MST_CLK_EN_BIT          2
#define HI6403_UART_CLK_EN_BIT             3

#define HI6403_DSP_AXI_CLKEN1              (BASE_ADDR_PAGE_CFG + 0x057)
#define HI6403_DW_AXI_GLB_CG_EN_BIT        0
#define HI6403_IOS_CG_EN_BIT               1

#define HI6403_DSP_CTRL1                   (BASE_ADDR_PAGE_CFG + 0x05D)
#define HI6403_HIFI_OCDHALTONRST_BIT      0

#define HI6403_DSP_CTRL2                   (BASE_ADDR_PAGE_CFG + 0x05E)
#define HI6403_HIFI_DEBUGRST_BIT      0

#define HI6403_DSP_CG_CTRL0                (BASE_ADDR_PAGE_CFG + 0x05F)
#define HI6403_DSP_CG_CTRL1                (BASE_ADDR_PAGE_CFG + 0x060)

#define HI6403_DSP_LP_CFG                  (BASE_ADDR_PAGE_CFG + 0x077)
#define HI6403_SC_PD1_PWRDN_EN_BIT         0
#define HI6403_SC_PD1_PWRUP_EN_BIT         1
#define HI6403_SC_PD_HD_BP_BIT             2

#define HI6403_EC_REG_DSP1                 (BASE_ADDR_PAGE_CFG + 0x09D)

/* S2 PORT FS CONFIG */
#define HI6403_S2_CLK_CFG_REG           (BASE_ADDR_PAGE_DIG + 0x0B0)
#define HI6403_S2_SRCOR_CLK_BIT         7
#define HI6403_S2_SRCOL_CLK_BIT         6
#define HI6403_S2_SRCIR_CLK_BIT         5
#define HI6403_S2_SRCIL_CLK_BIT         4
#define HI6403_S2_CLKEN_BIT             3
#define HI6403_S2_CLK_SEL_BIT           0
#define HI6403_S2_CLK_CFG_REG1          (BASE_ADDR_PAGE_DIG + 0x0B1)
#define HI6403_DSP_IF_OUT_FS_CFG        4
#define HI6403_DSP_IF_IN_FS_CFG         0

#define HI6403_S3_CLK_CFG_REG           (BASE_ADDR_PAGE_DIG + 0x0B2)
#define HI6403_S3_CLK_EN_BIT            3
#define HI6403_S3_CLK_FS_SEL_BIT        0

#define HI6403_S3_CLK_CFG_REG1          (BASE_ADDR_PAGE_DIG + 0x0B3)
#define HI6403_S3_LR_CLK_FS_BIT         4

/* S4 PORT FS CONFIG */
#define HI6403_S4_CLK_CFG_REG           (BASE_ADDR_PAGE_DIG + 0x0B4)
#define HI6403_S4_SRCOR_CLK_BIT         7
#define HI6403_S4_SRCOL_CLK_BIT         6
#define HI6403_S4_SRCIR_CLK_BIT         5
#define HI6403_S4_SRCIL_CLK_BIT         4
#define HI6403_S4_CLKEN_BIT             3
#define HI6403_S4_CLK_SEL_BIT           0

#define HI6403_S4_CLK_CFG_REG1          (BASE_ADDR_PAGE_DIG + 0x0B5)

#define HI6403_DACL_SRC_MIXER_GAIN_REG  (BASE_ADDR_PAGE_DIG + 0x0B7)
#define HI6403_DACL_MIXER_GAIN_1_BIT    0
#define HI6403_DACL_MIXER_GAIN_2_BIT    2

#define HI6403_DACR_SRC_MIXER_GAIN_REG  (BASE_ADDR_PAGE_DIG + 0x0BA)
#define HI6403_DACR_MIXER_GAIN_1_BIT    0
#define HI6403_DACR_MIXER_GAIN_2_BIT    2

/* slimbus port fs config */
#define HI6403_SLIM0_CLK_CFG_REG        (BASE_ADDR_PAGE_DIG + 0x0C3)
#define HI6403_SLIM1_CLK_CFG_REG        (BASE_ADDR_PAGE_DIG + 0x0C4)
#define HI6403_SLIM2_CLK_CFG_REG        (BASE_ADDR_PAGE_DIG + 0x0C5)
#define HI6403_SLIM3_CLK_CFG_REG        (BASE_ADDR_PAGE_DIG + 0x0C6)
#define HI6403_SLIM4_CLK_CFG_REG        (BASE_ADDR_PAGE_DIG + 0x0C7)
#define HI6403_SLIM5_CLK_CFG_REG        (BASE_ADDR_PAGE_DIG + 0x0C8)
#define HI6403_SLIM6_CLK_CFG_REG        (BASE_ADDR_PAGE_DIG + 0x0C9)
#define HI6403_SLIM7_CLK_CFG_REG        (BASE_ADDR_PAGE_DIG + 0x0CA)

/* 0.5dB uplink step pga gain */
#define HI6403_ADC0L_05PGA_GAIN_REG     (BASE_ADDR_PAGE_DIG + 0x22A)
#define HI6403_ADC0L_05PGA_GAIN_BIT     0
#define HI6403_ADC0R_05PGA_GAIN_REG     (BASE_ADDR_PAGE_DIG + 0x22D)
#define HI6403_ADC0R_05PGA_GAIN_BIT     0
#define HI6403_ADC1L_05PGA_GAIN_REG     (BASE_ADDR_PAGE_DIG + 0x230)
#define HI6403_ADC1L_05PGA_GAIN_BIT     0
#define HI6403_ADC1R_05PGA_GAIN_REG     (BASE_ADDR_PAGE_DIG + 0x233)
#define HI6403_ADC1R_05PGA_GAIN_BIT     0

#define HI6403_CODEC_DPCLK_REG          (BASE_ADDR_PAGE_DIG + 0x1D8)
#define HI6403_CODEC_DPCLK_BIT          0

/* MAD */
#define HI6403_SC_CODEC_MUX_SEL1_3      (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x00F)
#define HI6403_MAD_MIN_CHAN_ENG         (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x107)
#define HI6403_MAD_INE                  (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x108)
#define HI6403_MAD_SNR_THRE             (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x109)
#define HI6403_MAD_BAND_THRE            (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x10B)
#define HI6403_MAD_SCALE                (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x10D)
#define HI6403_MAD_CNT_THRE             (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x10E)
#define HI6403_MAD_AUTO_ACT_TIME_L      (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x10F)
#define HI6403_MAD_PLL_TIME_L           (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x111)
#define HI6403_MAD_ADC_TIME_H           (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x112)
#define HI6403_MAD_ADC_TIME_L           (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x113)
#define HI6403_MAD_ANA_TIME_H           (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x114)
#define HI6403_MAD_ANA_TIME             (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x115)
#define HI6403_MAD_OMIT_SAMP            (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x116)
#define HI6403_MAD_VAD_NUM              (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x117)
#define HI6403_MAD_ANA_EN_BPCLTRL       (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x118)
#define HI6403_MAD_VAD_TIME_H           (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x119)
#define HI6403_MAD_VAD_TIME_L           (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x11A)
#define HI6403_MAD_SLEEP_TIME_L         (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x11C)
#define HI6403_MAD_SNR_THRE_SUM         (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x11D)

#define HI6403_MAD_CTRL                 (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x11E)
#define HI6403_MAD_EN_BIT 0
#define HI6403_MAD_INT_EN_BIT 5
#define HI6403_MAD_VAD_AO_BIT 6

#define HI6403_MAD_BUFFER_CTRL0         (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x123)

#define HI6403_MAD_BUFFER_CTRL1         (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x124)
#define HI6403_MAD_BUF_EN_BIT 5

#define HI6403_MAD_ALPHA_EN1            (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x125)
#define HI6403_MAD_SRCDN_CTRL           (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x236)
#define HI6403_MIC1_SRCDN_CTRL          (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x237)
#define HI6403_MIC2_SRCDN_CTRL          (CODEC_BASE_ADDR + BASE_ADDR_PAGE_DIG + 0x238)

#define HI6403_MAD_RMS_TIME1            (BASE_ADDR_PAGE_DIG + 0x09d)
#define HI6403_MAD_RMS_DIFF_THRE0       (BASE_ADDR_PAGE_DIG + 0x09e)
#define HI6403_MAD_RMS_DIFF_THRE1       (BASE_ADDR_PAGE_DIG + 0x09f)
#define HI6403_MAD_FILTER_ID            (BASE_ADDR_PAGE_DIG + 0x0AA)
#define HI6403_MAD_FILTER_ID_BIT        2
#define HI6403_MAD_FILTER_ID1           (BASE_ADDR_PAGE_DIG + 0x0AA)

/* dig reg end */
#endif
